@@ -13,14 +13,7 @@ of other types.
 
 use base qw/Lire::Config::CompoundSpec/;
 
-use Lire::Config::Value;
-
-sub instance {
-    my $self = shift;
-    return new Lire::Config::List(@_, 'spec' => $self );
-}
-
-sub instance_class_ {
+sub instance_class {
     return "Lire::Config::List";
 }
 
@@ -31,7 +24,7 @@ __END__
 
 =head1 VERSION
 
-$Id: ListSpec.pm,v 1.2 2004/03/17 17:52:45 wsourdeau Exp $
+$Id: ListSpec.pm,v 1.3 2004/05/27 14:58:29 flacoste Exp $
 
 =head1 AUTHORS
 
