@@ -51,6 +51,7 @@ sub new {
     $self->{'_filter_params'} = [];
     $self->{'_parent'} = undef;
     $self->{'_nested_queries'} = [];
+    $self->{'_joined_streams'} = [];
 
     return $self;
 }
@@ -67,6 +68,56 @@ sub stream_name {
     return $_[0]{'_stream_name'};
 }
 
+sub schema {
+    return Lire::DlfSchema::load_schema( $_[0]->{'_stream_name'} );
+}
+
+=pod
+
+=head2 join_stream( $stream_name )
+
+This method can be used to add an ExtendedSchema stream which will
+be joined in the query.
+
+=cut
+
+sub join_stream {
+    my ( $self, $stream_name ) = @_;
+
+    check_param( $stream_name, 'stream_name' );
+    croak "there is no schema: '$stream_name'"
+      unless Lire::DlfSchema->has_schema( $stream_name );
+
+    croak "'$stream_name' is already joined"
+      if grep { $_ eq $stream_name } @{ $self->joined_streams() };
+
+    croak "can only join streams on root query"
+      if defined $self->{'_parent'};
+
+    my $joined_schema = Lire::DlfSchema::load_schema( $stream_name );
+    croak "cannot join '$stream_name' with '$self->{'_stream_name'}'"
+      unless $self->schema()->can_join_schema( $joined_schema );
+
+    push @{$self->{'_joined_streams'}}, $stream_name;
+
+    return;
+}
+
+=pod
+
+=head2 joined_streams()
+
+Returns as an array reference all the streams that are part of the
+query.
+
+=cut
+
+sub joined_streams {
+    my $self = $_[0];
+
+    return [ $self->{'_stream_name'}, @{$self->{'_joined_streams'}} ];
+}
+
 =pod
 
 =head2 release()
@@ -85,12 +136,18 @@ sub release {
     foreach my $query ( @{ $self->nested_queries() } ) {
         $query->release();
     }
+
+    return;
 }
 
 sub _schema_has_field {
     my ( $self, $field_name ) = @_;
 
-    return Lire::DlfSchema::load_schema( $self->{'_stream_name'} )->has_field( $field_name );
+    foreach my $schema ( @{$self->joined_streams()} ) {
+        return 1
+          if Lire::DlfSchema::load_schema( $schema )->has_field( $field_name );
+    }
+    return 0;
 }
 
 sub _field_by_name {
@@ -121,6 +178,16 @@ sub create_nested_query {
     return $nested;
 }
 
+sub _root_query {
+    my $self = $_[0];
+
+    my $root = $self;
+    while ( defined $root->{'_parent'} ) {
+        $root = $root->{'_parent'};
+    }
+    return $root;
+}
+
 =pod
 
 =head2 nested_queries()
@@ -147,7 +214,15 @@ sub _find_field_def {
     return undef;
 }
 
-sub _is_field_defined {
+=pod
+
+=head2 has_field( $field_name )
+
+Returns true if there is a field $field_name defined in the query.
+
+=cut
+
+sub has_field {
     my ( $self, $field_name ) = @_;
 
     return defined $self->_find_field_def( $field_name );
@@ -157,6 +232,10 @@ sub _is_field_defined {
 
 =head2 field_def( $field_name )
 
+Returns the SQL expression that is associated with the field
+$field_name in the query. This method will throw an exception if
+there is no field $field_name defined in the query.
+
 =cut
 
 sub field_def {
@@ -212,6 +291,7 @@ sub _nested_queries_subtree {
         push @$subtree, $child;
         $child->_nested_queries_subtree( $subtree );
     }
+    return;
 }
 
 sub _field_name {
@@ -224,6 +304,9 @@ sub _field_name {
 
 =head2 fields()
 
+Returns the name of the fields defined as simple fields in an array
+reference. These are fields added through the add_field() method.
+
 =cut
 
 sub fields {
@@ -236,6 +319,9 @@ sub fields {
 
 =head2 group_fields()
 
+Returns the name of the fields defined as group fields in an array
+reference. These are fields added through the add_group_field() method.
+
 =cut
 
 sub group_fields {
@@ -251,6 +337,9 @@ sub group_fields {
 
 =head2 aggr_fields()
 
+Returns the name of the fields defined as aggregate fields in an array
+reference. These are fields added through the add_aggr_field() method.
+
 =cut
 
 sub aggr_fields {
@@ -278,19 +367,21 @@ sub _add_field {
         croak "field name should contain only alphanumeric characters: '$alias'"
           unless ( check_xml_name ($alias) );
         croak "'$alias' is already defined in the query"
-          if ( $self->_is_field_defined( $alias ) );
+          if ( $self->has_field( $alias ) );
     } else {
         croak "field name should contain only alphanumeric characters: '$field'"
           unless ( check_xml_name ($field) );
         croak "no field '$field' in '$self->{'_stream_name'}' schema"
           unless ( $self->_schema_has_field( $field ) || $type ne 'simple' );
         croak "'$field' is already defined in the query"
-          if ( $self->_is_field_defined( $field ) );
+          if ( $self->has_field( $field ) );
     }
 
     my $field_ref = { 'field' => $field, 'alias' => $alias, 'type' => $type };
     push @{$self->{'_fields'}}, $field_ref;
     $self->{'_field_refs'}{(defined $alias) ? $alias : $field} = $field_ref;
+
+    return;
 }
 
 =pod
@@ -302,8 +393,7 @@ field name. The second represents an expression that will then be aliased
 with the specified field name. Only the field name is mandatory.
 
 Certain restrictions apply: simple fields cannot be added to queries
-containing either subqueries or group fields, neither can they be added
-to subqueries themselves.
+containing either subqueries or group fields.
 
 =cut
 
@@ -322,6 +412,8 @@ sub add_field {
     } else {
       $self->_add_field( $field_name, 'simple' );
     }
+
+    return;
 }
 
 =pod
@@ -342,6 +434,8 @@ sub add_aggr_field {
     check_param ( $aggregate, 'aggregate' );
 
     $self->_add_field( $aggregate, 'aggr', $field_name );
+
+    return;
 }
 
 =pod
@@ -369,6 +463,8 @@ sub add_group_field {
     } else {
         $self->_add_field( $field_name, 'group' );
     }
+
+    return;
 }
 
 
@@ -386,6 +482,8 @@ sub set_order_by_clause {
 
     $self->{'_sort_spec'} = undef;
     $self->{'_order_by'} = ( defined $clause && $clause ne '' ) ? $clause : undef;
+
+    return;
 }
 
 =pod 
@@ -450,6 +548,10 @@ sub set_sort_spec {
 
 =head2 sort_spec()
 
+Returns the sort specification that was set using set_sort_spec(). If
+no sort specification was set (or it was set using the
+set_order_by_clause() method), this will be undef.
+
 =cut
 
 sub sort_spec {
@@ -472,6 +574,8 @@ sub set_limit {
     croak "'limit' parameter should be an integer: '$limit'"
       unless ( !defined $limit || check_int( $limit ) );
     $self->{'_limit'} = (defined $limit) ? $limit : 0;
+
+    return;
 }
 
 =pod 
@@ -516,6 +620,8 @@ sub set_filter_clause {
 
     $self->{'_filter_clause'} = ($clause ne '') ? $clause : undef;
     $self->{'_filter_params'} = \@params;
+
+    return;
 }
 
 =pod 
@@ -584,16 +690,42 @@ sub _sql_select_clause {
 sub _sql_from_clause {
     my $self = $_[0];
 
-    return "FROM " . sql_quote_name( "dlf_" . $self->{'_stream_name'} );
+    my $schema = $self->schema();
+    my @tables = ( $schema->sql_table() );
+    if ( $schema->isa( 'Lire::ExtendedSchema' ) ) {
+        unshift @tables, $schema->base()->sql_table();
+    } elsif ( $self->_needs_links_table() ) {
+        push @tables, $schema->sql_table( '', '_links' );
+    }
+
+    foreach my $name ( @{$self->{'_joined_streams'}} ) {
+        push @tables, Lire::DlfSchema::load_schema( $name )->sql_table();
+    }
+
+    return "FROM " . join( ", ", @tables );
+}
+
+sub _needs_links_table {
+    my $self = $_[0];
+
+    my $schema = $self->schema();
+    return ( $schema->isa( 'Lire::DerivedSchema' )
+             && grep {
+                 my $joined = Lire::DlfSchema::load_schema( $_ );
+                 return ( ! $joined->isa( 'Lire::ExtendedSchema' )
+                          || $joined->base() ne $schema )
+             } @{$self->{'_joined_streams'}} );
 }
 
 sub _sql_where_clause {
     my $self = $_[0];
 
+    my @elmnts = @{$self->_sql_where_join_elements()};
+
     my $filter_collector = sub {
         defined $_[0]{'_filter_clause'} ? $_[0]{'_filter_clause'} : ()
     };
-    my @elmnts = @{$self->_traverse_from_parent( $filter_collector )};
+    push @elmnts, @{$self->_traverse_from_parent( $filter_collector )};
 
     push @elmnts, $self->{'_filter_clause'}
       if ( defined $self->{'_filter_clause'} );
@@ -601,6 +733,38 @@ sub _sql_where_clause {
     return @elmnts ? "WHERE " . join ( " AND ", @elmnts )  : ();
 }
 
+sub _sql_where_join_elements {
+    my $self = $_[0];
+
+    my $schema = $self->schema();
+    my @elmnts = ();
+    if ( $self->_needs_links_table() ) {
+        push @elmnts, $schema->sql_table() . ".dlf_id = " . $schema->sql_table( '', '_links' ) . ".src_id";
+    }
+    foreach my $name ( @{ $self->joined_streams() } ) {
+        my $joined = Lire::DlfSchema::load_schema( $name );
+        if ( $schema->isa( 'Lire::DerivedSchema' ) ) {
+            if ( $joined->isa( 'Lire::ExtendedSchema' )
+                 && $joined->base() eq $schema )
+            {
+                push( @elmnts, $schema->sql_table() . '.dlf_id = '
+                      . $joined->sql_table() . '.dlf_id' );
+            } elsif ( ( $joined->isa( 'Lire::ExtendedSchema' )
+                        && $joined->base() ne $schema )
+                      || $joined eq $schema->base() )
+            {
+                push( @elmnts, $schema->sql_table( '', '_links' ) .'.link_id = '
+                      . $joined->sql_table() . '.dlf_id' );
+            }
+        } elsif ( $joined->isa( 'Lire::ExtendedSchema' ) ) {
+            push( @elmnts, $joined->base()->sql_table() . '.dlf_id = '
+                  . $joined->sql_table() . '.dlf_id' );
+        }
+    }
+
+    return \@elmnts;
+}
+
 sub _sql_group_by_clause {
     my ( $self, $is_summary ) = @_;
 
@@ -682,8 +846,11 @@ sub execute {
     my ( $self, $store ) = @_;
 
     check_object_param( $store, 'store', 'Lire::DlfStore' );
-    croak "store doesn't contain a '$self->{'_stream_name'}' stream"
-      unless $store->has_dlf_stream( $self->{'_stream_name'} );
+
+    foreach my $stream ( @{ $self->joined_streams() } ) {
+        croak "store doesn't contain a '$stream' stream"
+          unless $store->has_dlf_stream( $stream );
+    }
 
     return Lire::DlfResult->new( $self, $self->_as_sql(), $store );
 }
@@ -700,8 +867,11 @@ sub execute_summary {
     my ( $self, $store ) = @_;
 
     check_object_param( $store, 'store', 'Lire::DlfStore' );
-    croak "store doesn't contain a '$self->{'_stream_name'}' stream"
-      unless $store->has_dlf_stream( $self->{'_stream_name'} );
+
+    foreach my $stream ( @{ $self->joined_streams() } ) {
+        croak "store doesn't contain a '$stream' stream"
+          unless $store->has_dlf_stream( $stream );
+    }
 
     return Lire::DlfResult->new( $self, $self->_as_summary_sql(), $store );
 }
@@ -717,15 +887,15 @@ __END__
 
 Lire::DlfQuery(3pm) Lire::DlfStream(3pm) Lire::DlfStore(3pm)
 
-=head1 VERSION
-
-$Id: DlfQuery.pm,v 1.35 2004/03/26 00:27:34 wsourdeau Exp $
-
-=head1 AUTHOR
+=head1 AUTHORS
 
   Francis J. Lacoste <flacoste@logreport.org>
   Wolfgang Sourdeau <Wolfgang.Sourdeau@Contre.COM>
 
+=head1 VERSION
+
+$Id: DlfQuery.pm,v 1.43 2004/05/17 17:05:19 wsourdeau Exp $
+
 =head1 COPYRIGHT
 
 Copyright (C) 2003 Stichting LogReport Foundation LogReport@LogReport.org
