@@ -4,18 +4,19 @@ use strict;
 
 use vars qw/ %SCHEMA_CACHE /;
 
+use Carp;
+use Locale::TextDomain 'lire';
 use XML::Parser;
 
 use Lire::Config::Build qw/ ac_info /;
 use Lire::Config;
+use Lire::DataTypes qw/ check_xml_name check_superservice check_type /;
 use Lire::Field;
-use Lire::DataTypes qw/ :xml :basic :special /;
 use Lire::DerivedSchema;
 use Lire::ExtendedSchema;
+use Lire::DlfQuery;
 use Lire::I18N qw/ bindtextdomain dgettext dgettext_para /;
-use Lire::Utils qw/ sql_quote_name check_param /;
-
-use Carp;
+use Lire::Utils qw/ sql_quote_name check_param check_object_param /;
 
 BEGIN {
     %SCHEMA_CACHE = ();
@@ -34,21 +35,33 @@ In DLF converters:
     use Lire::DlfSchema;
 
     my $schema = Lire::DlfSchema::load_schema( "email" );
+    my $fields = $schema->fields();
 
-    my $dlf_maker = $schema->make_hashref2asciidlf_func( qw/time msgid
-	      from_user from_domain from_relay_host from_relay_ip
-	      size delay to_user to_domain to_relay_host to_relay_ip
-	      stat / );
-
+    my $dlf_id = $schema->field( 'dlf_id' );
+    my $dlf_src = $schema->field( 'dlf_source' );
 
 =head1 DESCRIPTION
 
 This module is the interface to the Lire DLF Schemas defined in XML
 files. A schema defines the order of the fields along with their
-names, descriptions, types and default values.
+names, descriptions and types.
 
-This module also includes one function which is mandatory to use for
-old style DLF converters: make_hashref2asciidlf_func().
+Each DlfSchema have at least two predefined fields: 
+
+=over
+
+=item dlf_id
+
+This is an integer which uniquely identify a DLF record in its stream.
+Its used to link the record to its extended schemas fields and also to
+link the record to the derived schemas records.
+
+=item dlf_source
+
+This is an identifier which can be used to track the record the
+ImportJob that created it.
+
+=back
 
 =head1 ACCESSING A SCHEMA OBJECT
 
@@ -77,21 +90,14 @@ sub load_schema {
     croak "invalid superservice: $super"
       unless Lire::DlfSchema->has_superservice( $super );
 
+    return $SCHEMA_CACHE{$name}
+      if $SCHEMA_CACHE{$name};
+
     my $file = Lire::DlfSchema->_schema_file( $name );
     croak "can't find XML schema definition for $name in ",
       join( ":", @{Lire::Config->get( 'lr_schemas_path' )} ),"\n"
         unless defined $file;
 
-    # If the schema is in the cache, make sure
-    # the in-memory version is up-to-date.
-    if ( exists $SCHEMA_CACHE{$name} ) {
-        my $cache_entry = $SCHEMA_CACHE{$name};
-
-        return $cache_entry->{'schema'}
-          if $file eq $cache_entry->{'file'} &&
-            (stat $file)[9] <= $cache_entry->{'mtime'}
-    }
-
     my $file_h;
     open ( $file_h, "$file")
       or croak "can't open XML schema $file for $name schema: $!";
@@ -100,41 +106,28 @@ sub load_schema {
 						    'Init'  => \&Init,
 						    'Final' => \&Final,
 						    'Start' => \&Start,
-						    'End'	  => \&End,
+						    'End'   => \&End,
 						    'Char'  => \&Char,
 						   },
 				   'Namespaces' => 1,
 				   'NoLWP'      => 1,
 				 );
-    my $dlf;
-
-    eval {
-	$dlf = $parser->parse( $file_h );
-    };
+    my $dlf_schema = eval { $parser->parse( $file_h ) };
     croak "error while parsing XML definition of $name: $@"
       if $@;
-
     close $file_h;
 
     # Sanity checks
-    croak "$file has '", $dlf->superservice, "' as superservice attribute when it should have '", $super, "'\n"
-	if $dlf->superservice ne $super;
-    croak "$file has '", $dlf->id, "' as id attribute when it should have '", $name, "'\n"
-      if $dlf->id ne $name;
+    croak "$file has '", $dlf_schema->superservice(), "' as superservice attribute when it should have '", $super, "'\n"
+	if $dlf_schema->superservice() ne $super;
+    croak "$file has '", $dlf_schema->id(), "' as id attribute when it should have '", $name, "'\n"
+      if $dlf_schema->id() ne $name;
 
-    $SCHEMA_CACHE{$name} = { 'file'   => $file,
-			     'schema' => $dlf,
-			     'mtime'  => (stat $file)[9],
-			   };
-
-    $SCHEMA_CACHE{$name}{'schema'};
+    return $SCHEMA_CACHE{$name} = $dlf_schema;
 }
 
 sub new {
-    my $proto = shift;
-    my $class = ref( $proto) || $proto;
-
-    my %attr = @_;
+    my ( $class, %attr ) = @_;
 
     check_param( $attr{'superservice'}, 'superservice',
                  \&check_superservice );
@@ -150,6 +143,22 @@ sub new {
                        'description'	    => undef,
                      }, $class;
 
+    $self->add_field( new Lire::Field( 'name' => 'dlf_id',
+                                       'type' => 'id',
+                                       'label' => __( 'Dlf ID' ),
+                                       'description' => '<para>' . __( <<EOD ) . '</para>'  ) );
+This field contains an integer which uniquely identify this DLF record
+in the stream.
+EOD
+
+    $self->add_field( new Lire::Field( 'name' => 'dlf_source',
+                                       'type' => 'string',
+                                       'label' => __( 'Dlf Source' ),
+                                       'description' => '<para>' . __( <<EOD ) . '</para>'  ) );
+This field contains an identifier relating the record to the process
+that created it.
+EOD
+
     bindtextdomain( "lire-" . $self->superservice(),
                     ac_info( 'LR_PERL5LIB' ) . "/LocaleData" );
 
@@ -188,7 +197,8 @@ sub has_superservice {
                                 && index($_[0], "-") == -1 ) },
                  'invalid superservice schema name' );
 
-    return defined $self->_schema_file( $superservice );
+    return ( defined $SCHEMA_CACHE{$superservice}
+             || defined $self->_schema_file( $superservice ) );
 }
 
 =pod
@@ -206,7 +216,8 @@ sub has_schema {
     check_param( $schema_name, 'schema_name', \&check_xml_name,
                  'invalid schema name' );
 
-    return defined $self->_schema_file( $schema_name );
+    return ( defined $SCHEMA_CACHE{$schema_name} 
+             ||defined $self->_schema_file( $schema_name ) );
 }
 
 sub _schema_file {
@@ -245,7 +256,7 @@ Returns the name of the available schemas in an array.
 sub schemas {
     my $self = $_[0];
 
-    my @schemas = ();
+    my @schemas = keys %SCHEMA_CACHE;
     foreach my $dir ( @{ Lire::Config->get( 'lr_schemas_path' ) } ) {
         next unless -d $dir && -r $dir;
         opendir my $dh, $dir
@@ -277,7 +288,7 @@ different than the superservice's name.)
 =cut
 
 sub id {
-    $_[0]->{'id'};
+    return $_[0]->{'id'};
 }
 
 =pod
@@ -296,32 +307,41 @@ sub superservice {
 
 =pod
 
-=head2 title()
+=head2 title( [$new_title] )
 
-This method will return the human readable title of the schema. (This
-is the content of the title element in the XML specification.)
+This method will return (or change) the human readable title of the
+schema. (This is the content of the title element in the XML
+specification.)
 
 =cut
 
 sub title {
     my $self = $_[0];
 
+    if ( @_ == 2 ) {
+        check_param( $_[1], 'title' );
+        $self->{'title'} = $_[1];
+    }
     return dgettext( "lire-$self->{'superservice'}", $self->{'title'} );
 }
 
 =pod
 
-=head2 description()
+=head2 description( [$new_description] )
 
-This method will return the description of the schema. (This is the
-content of the description element in the XML specification.) Be aware
-that this will most likely contain DocBook markup.
+This method will return (or change) the description of the schema.
+(This is the content of the description element in the XML
+specification.) Be aware that this will most likely contain DocBook
+markup.
 
 =cut
 
 sub description {
     my $self = $_[0];
 
+    if ( @_ == 2 ) {
+        $self->{'description'} = $_[1];
+    }
     return dgettext_para( "lire-$self->{'superservice'}",
                           $self->{'description'} );
 }
@@ -345,7 +365,27 @@ sub field_by_pos {
     croak "invalid field number: $pos"
       unless $pos < @{$self->{'fields_by_pos'}} && $pos >= 0;
 
-    $self->{'fields_by_pos'}[$pos];
+    return $self->{'fields_by_pos'}[$pos];
+}
+
+=pod
+
+=head2 add_field( $field )
+
+Adds the Lire::Field $field to this schema.
+
+=cut
+
+sub add_field {
+    my ( $self, $field ) = @_;
+
+    check_object_param( $field, 'field', 'Lire::Field' );
+
+    push @{$self->{'fields_by_pos'}}, $field;
+    $self->{'fields_by_name'}{$field->name()} = $field;
+    $field->{'pos'} = $#{$self->{'fields_by_pos'}};
+
+    return;
 }
 
 =pod
@@ -387,15 +427,15 @@ sub field {
     croak "no field by that name: $name"
       unless $self->has_field( $name );
 
-    $self->{'fields_by_name'}{$name};
+    return $self->{'fields_by_name'}{$name};
 }
 
 =pod
 
 =head2 fields()
 
-    my $fields = $schema->fields;
-    my @fields = $schema->fields;
+    my $fields = $schema->fields();
+    my @fields = $schema->fields();
 
 In array context, this method will return an array containing all the
 fields (as Lire::Field(3pm) objects) in the schema. The order of the
@@ -408,7 +448,20 @@ ARRAY.
 =cut
 
 sub fields {
-    wantarray ? @{$_[0]{'fields_by_pos'}} : $_[0]{'fields_by_pos'};
+    return wantarray ? @{$_[0]{'fields_by_pos'}} : $_[0]{'fields_by_pos'};
+}
+
+=pod
+
+=head2 field_names()
+
+Returns the name of the fields in this schema. The names are in the
+same order than the fields.
+
+=cut
+
+sub field_names {
+    return map { $_->name() } $_[0]->fields();
 }
 
 =pod
@@ -422,7 +475,7 @@ This method returns the number of fields in the schema.
 =cut
 
 sub field_count {
-    scalar @{$_[0]->{'fields_by_pos'}};
+    return scalar @{$_[0]->{'fields_by_pos'}};
 }
 
 =pod
@@ -440,7 +493,7 @@ defines the sort order of the DLF records.
 sub timestamp_field {
     my ($self) = @_;
 
-    $self->field( $self->{'timestamp_field'} );
+    return $self->field( $self->{'timestamp_field'} );
 }
 
 =pod
@@ -466,64 +519,76 @@ sub is_schema_compatible {
     return $schema eq $self->{'id'};
 }
 
+=pod
+
+=head2 can_join_schema( $schema ) 
+
+Returns true if $schema can be joined with this schema. For a
+DlfSchema, this will be true only when $schema is an ExtendedSchema of
+this schema.
+
+=cut
+
+sub can_join_schema {
+    my ( $self, $schema ) = @_;
+
+    check_object_param( $schema, 'schema', 'Lire::DlfSchema' );
+
+    return ( $schema->isa( 'Lire::ExtendedSchema' )
+             && $schema->base() eq $self );
+}
+
 sub ascii_dlf_escape_field {
     # Escape the value :
     #   replace space with _
     #   replace 8 bit chars with ?
     #   replace control chars with ?
-    $_[0] =~ tr/ \200-\377\000-\037/_?/;
+    return $_[0] =~ tr/ \200-\377\000-\037/_?/;
 }
 
-=pod
+# This method is part of the old style, now deprecated, DLF converter API.
 
-=head2 make_hashref2asciidlf_func()
+# It takes as parameters a list of field's names that are available in
+# the DLF output by the converter. (Not all services in a given
+# superservice will support the whole or the same subset of the
+# superservice's fields. Unsupported fields should contain the value
+# C<LIRE_NOTAVAIL> in the output DLF.)
 
-This method is part of the old style, now deprecated, DLF converter API.
+# This method will return an anonymous subroutine that should be used by
+# the DLF converter to create the DLF records. The generated subroutine
+# takes as parameter a hash reference representing the DLF record to
+# create. It returns an array reference representing the DLF record's
+# fields. It will make sure that the field's values are in the correct
+# order, that the unavailable fields are marked correctly, that missing
+# fields are defaulted and that the field's values are escaped
+# appropriately.
 
-It takes as parameters a list of field's names that are available in
-the DLF output by the converter. (Not all services in a given
-superservice will support the whole or the same subset of the
-superservice's fields. Unsupported fields should contain the value
-C<LIRE_NOTAVAIL> in the output DLF.)
+# The hash's keys should be the DLF record's field names with the value
+# of the field associated to the key. All the fields that are available
+# (as specified when the method is called) which are undefined or that
+# aren't present in the hash will be set in the output DLF record to the
+# field's default value specified in the schema. Extra keys in the hash
+# will be ignored. Fields that aren't supported (as specified when the
+# subroutine was created by the make_hashref2asciidlf_func() method)
+# will contain the C<LIRE_NOTAVAIL> value.
 
-This method will return an anonymous subroutine that should be used by
-the DLF converter to create the DLF records. The generated subroutine
-takes as parameter a hash reference representing the DLF record to
-create. It returns an array reference representing the DLF record's
-fields. It will make sure that the field's values are in the correct
-order, that the unavailable fields are marked correctly, that missing
-fields are defaulted and that the field's values are escaped
-appropriately.
+# One can write an ASCII DLF by printing the returned array reference
+# using a space as the join delimiter:
 
-The hash's keys should be the DLF record's field names with the value
-of the field associated to the key. All the fields that are available
-(as specified when the method is called) which are undefined or that
-aren't present in the hash will be set in the output DLF record to the
-field's default value specified in the schema. Extra keys in the hash
-will be ignored. Fields that aren't supported (as specified when the
-subroutine was created by the make_hashref2asciidlf_func() method)
-will contain the C<LIRE_NOTAVAIL> value.
+#     my $dlf = $dlf_maker->( $hash_dlf );
+#     print join( " ", @$dlf ), "\n";
 
-One can write an ASCII DLF by printing the returned array reference
-using a space as the join delimiter:
-
-    my $dlf = $dlf_maker->( $hash_dlf );
-    print join( " ", @$dlf ), "\n";
-
-See the SYNOPSIS section for an example.
-
-Beware!  New DLF convertors should use the Lire::DlfConverterProcess
-interface.
-
-=cut
+# See the SYNOPSIS section for an example.
 
+# Beware!  New DLF convertors should use the Lire::DlfConverterProcess
+# interface.
 sub make_hashref2asciidlf_func {
     my ( $self, @fields ) = @_;
 
     my %avail = map { $_ => 1 } @fields;
     my @ascii_dlf_tmpl = ();
     foreach my $field ( @{$self->fields}) {
-	push @ascii_dlf_tmpl, [ $field->name, $field->default ];
+	push @ascii_dlf_tmpl, [ $field->name, $field->default() ];
     }
 
     return sub {
@@ -550,84 +615,167 @@ sub make_hashref2asciidlf_func {
     };
 }
 
-sub make_key_access_func {
-    my ( $self, @fields ) = @_;
 
-    # Compile a key maker function
-    my @pos = ();
-    foreach my $f ( @fields ) {
-	push @pos, $self->field( $f )->pos;
-    }
-    my $check_undef_code = join( ' || ', map { '! defined $_[0]->[' . $_ . ']' } @pos);
-    my $dlf_access_code = join ", ", map { '$_[0]->[' . $_ . ']' } @pos;
-    my $key_maker_code = <<EOC;
-sub {
-    return undef if $check_undef_code;
-    return join( ",", , $dlf_access_code);
-}
-EOC
-    my $sub = eval $key_maker_code;
-    croak "error compiling key maker function ($key_maker_code): $@"
-      if $@;
+=pod
 
-    return $sub;
+=head1 SQL Related Methods
+
+These methods are used to map DLF record into SQL tables.
+
+=head2 sql_table()
+
+Returns the SQL table used to hold the DLF records of this schema.
+
+=cut
+
+sub sql_table {
+    my ( $self, $prefix, $suffix ) = @_;
+
+    $prefix = ""
+      unless defined $prefix;
+    $suffix = ""
+      unless defined $suffix;
+
+    return sql_quote_name( $prefix . 'dlf_' . $_[0]->{'id'} . $suffix );
 }
 
 =pod
 
-=head2 make_dlf_sort_func( @fields )
+=head2 create_sql_schema( $dlf_store, [ $remove ] )
 
-Returns an anonymous subroutine that can be used to compare the
-relative sort order (-1, 0, 1) of two DLF arrays. The @fields
-parameter contains the name of the field which are part of the sort
-key.
-
-The returned comparison function can be used like this 
-
-$func->( $dlf1, $dlf2 )
-
-It will returns -1 if DLF1 should sorted before DLF2; 0 when DLF1 and
-DLF2 should sort at the same place and 1 if DLF1 should sort after
-DLF2.
+This will create the SQL schemas necessary to hold the DLF records for
+this schema in the Lire::DlfStore. If $remove is true, a DROP TABLE
+will be done before creating the schema.
 
 =cut
 
-sub make_dlf_sort_func {
-    my ( $self, @fields ) = @_;
+sub create_sql_schema {
+    my ($self, $store, $remove ) = @_;
 
-    my @sort_ops = ();
-    foreach my $f ( @fields ) {
-	my $field = $self->field( $f );
-	my $i = $field->pos;
-	my $cmp = is_numeric_type( $field->type ) ? '<=>' : 'cmp';
-	push @sort_ops, '$_[0][' . $i . '] ' . $cmp . ' $_[1][' . $i . ']';
-    }
-    my $sort_code = "sub { " . join( " || ", @sort_ops ) . " }";
-    my $sort_func = eval $sort_code;
-    croak "error compiling sort comparison ($sort_code): $@" if $@;
+    check_object_param( $store, 'store', 'Lire::DlfStore' );
 
-    $sort_func;
+    $store->_dbh()->do( "DROP TABLE " . $self->sql_table() )
+      if $remove;
+    $store->_dbh()->do( $self->_create_sql_table_query() );
+
+    my $idx_sql = sprintf( "CREATE INDEX %s ON %s ( %s )",
+                           $self->sql_table( "", "_" . $self->{'timestamp_field'} . "_idx"),
+                           $self->sql_table(),
+                           $self->{'timestamp_field'} );
+    $store->_dbh()->do( $idx_sql );
+
+    return;
+}
+
+sub _create_sql_table_query {
+    return "CREATE TABLE " . $_[0]->sql_table() . " "
+      . $_[0]->_sql_fields_def();
 }
 
 =pod
 
-=head2 sql_fields_def()
+=head2 needs_sql_schema_migration( $dlf_store )
 
-This method returns a string which can be used in a SQL CREATE TABLE
-statement. IT only returns the field definitions like :
-
- (
-     ts TIMESTAMP,
-     int_field NUMBER(10,0)
- )
+This method will return true if the SQL schema isn't up-to-date in the
+DlfStore. The method migrate_sql_schema() can be used to bring the
+schema up to date.
 
 =cut
 
-sub sql_fields_def {
+sub needs_sql_schema_migration {
+    my ( $self, $store ) = @_;
+
+    check_object_param( $store, 'store', 'Lire::DlfStore' );
+
+    my $create_sql = $self->_create_sql_table_query();
+
+    # SQLite will remove trailing newline
+    chomp $create_sql;
+
+    my $sql = "SELECT sql FROM sqlite_master WHERE type = 'table' AND name=?";
+    my $sth = $store->_dbh()->prepare( $sql );
+    $sth->execute( $self->sql_table() );
+    my $table_def = $sth->fetchrow_arrayref();
+    $sth->finish();
+
+    return $table_def && $table_def->[0] ne $create_sql;
+}
+
+=pod
+
+=head2 migrate_sql_schema( $dlf_store )
+
+Updates the SQL schemas to the current version.
+
+=cut
+
+sub migrate_sql_schema {
+    my ( $self, $store ) = @_;
+
+    check_object_param( $store, 'store', 'Lire::DlfStore' );
+
+    # SQLite doesn't support ALTER TABLE
+    # Find the list of fields in common
+    my @fields = $self->_find_fields_in_schema( $store );
+
+    # Create temporary backup
+    my $sql = sprintf( "CREATE TEMP TABLE %s AS SELECT * FROM %s",
+                       $self->sql_table( "temp_" ),
+                       $self->sql_table() );
+    $store->_dbh()->do( $sql  );
+
+    # Recreate the schema
+    $self->create_sql_schema( $store, 1 );
+
+    # Migrate the data
+    my @common_fields = ();
+    foreach my $f ( @fields ) {
+        push @common_fields, $f if $self->has_field( $f );
+    }
+
+    $sql = $self->_migration_insert_query( \@common_fields );
+    $store->_dbh()->do( $sql );
+    $store->_dbh()->do( "DROP TABLE " . $self->sql_table( "temp_" ) );
+    return;
+}
+
+sub _find_fields_in_schema {
+    my ( $self, $store ) = @_;
+
+    # Since DBD::SQLite doesn't support the column_info API
+    # we run a query to find the fields present in the schema.
+    my $sth = $store->_dbh()->prepare( "SELECT * FROM " . $self->sql_table()
+                                       . " LIMIT 1" );
+    $sth->execute();
+
+    my @fields = @{$sth->{'NAME'}};
+    $sth->finish();
+
+    return @fields;
+}
+
+sub _migration_insert_query {
+    my ( $self, $common_fields ) = @_;
+
+    # New fields will be set to NULL
+    # Old fields aren't migrated
+
+    my $field_list = join (", ", map { sql_quote_name( $_ ) } @$common_fields);
+    return sprintf( "INSERT INTO %s (%s) SELECT %s FROM %s",
+                    $self->sql_table(),
+                    $field_list, $field_list,
+                    $self->sql_table( "temp_" ) );
+}
+
+sub _sql_fields {
+    return $_[0]->fields();
+}
+
+sub _sql_fields_def {
     my $self = $_[0];
 
     my @defs = ();
-    foreach my $f ( $self->fields() ) {
+    foreach my $f ( $self->_sql_fields() ) {
         push @defs, "    " . sql_quote_name( $f->name() ) . " " . 
           $f->sql_type();
     }
@@ -635,6 +783,95 @@ sub sql_fields_def {
     return "(\n" . join( ",\n", @defs ) . "\n)\n";
 }
 
+
+=pod
+
+=head2 dlf_query( $sort_spec )
+
+Returns a Lire::DlfQuery object which can be use to return all DLF
+records sorted according to $sort_spec. Sort spec is a white-space
+delimited list of sort field names. They must be present in the
+current schema. If the field's name is prefixed by '-', descending
+sort order will be used.
+
+=cut
+
+sub dlf_query {
+    my ( $self, $sort_spec ) = @_;
+
+    my $query = new Lire::DlfQuery( $self->{'id'} );
+    foreach my $f ( $self->fields() ) {
+        $query->add_field( $f->name() );
+    }
+
+    $query->set_sort_spec( $sort_spec )
+      if $sort_spec;
+
+    return $query;
+}
+
+=pod
+
+=head2 insert_sql_query()
+
+Returns the INSERT SQL statement that should be used to insert DLF
+records in the stream. A DBI::st handle prepared with that query needs
+to be passed as parameter to execute_insert_query().
+
+=cut
+
+sub sql_insert_query {
+    my $self = $_[0];
+
+    my @fields = map { $_->name() } $self->_sql_fields();
+    return "INSERT INTO " . $self->sql_table() . " ("
+      . join( ", ", map { sql_quote_name( $_ ) } @fields ) . ") VALUES ("
+      . join( ",", ("?") x scalar @fields  ) . ")";
+}
+
+=pod
+
+=head2 sql_clean_query( $with_time )
+
+Returns the DELETE statement that can be use to delete the DLF records
+in this schema. If $with_time is true, the query can be use for
+selective cleaning. One bind timestamp parameter should be passed when
+the query is executed and all records which are older than this
+timestamp will be deleted.
+
+=cut
+
+sub sql_clean_query {
+    my ($self, $with_time) = @_;
+
+    my $table = $self->sql_table();
+    if ( $with_time ) {
+        my $ts_field = sql_quote_name( $self->{'timestamp_field'} );
+        return qq{DELETE FROM $table WHERE $ts_field < ?};
+    } else {
+        return "DELETE FROM $table";
+    }
+}
+
+=pod
+
+=head2 sql_clean_period_query()
+
+Returns the DELETE statement that can be use to delete the DLF records
+in this schema. The query should be passed two bind parameters. These
+parameters will be the time boundaries between which records should be
+deleted from the schema.
+
+=cut
+
+sub sql_clean_period_query {
+    my $self = $_[0];
+
+    my $table = $self->sql_table();
+    my $ts_field = sql_quote_name( $self->{'timestamp_field'} );
+    return qq{DELETE FROM $table WHERE $ts_field >= ? AND $ts_field < ?};
+}
+
 use vars qw( $LDSML_NS %LDSML_ELEMENTS );
 
 BEGIN {
@@ -650,6 +887,8 @@ sub Init {
     $expat->{'lire_curr_schema'} = undef;
     $expat->{'lire_curr_field'}  = undef;
     $expat->{'lire_curr_desc'}   = undef;
+
+    return;
 }
 
 sub Final {
@@ -686,6 +925,7 @@ sub Start {
 	    error( $expat, "unknown element: $name" );
 	}
     }
+    return;
 }
 
 sub End {
@@ -716,6 +956,7 @@ sub End {
 	    error( $expat, "unknown element: $name" );
 	}
     }
+    return;
 }
 
 sub Char {
@@ -731,6 +972,7 @@ sub Char {
 	# Use original_string because we don't want parsed entities.
 	$expat->{'lire_curr_desc'}  .= $expat->original_string();
     }
+    return;
 }
 
 sub dlf_schema_start {
@@ -740,6 +982,7 @@ sub dlf_schema_start {
 	$expat->{'lire_curr_schema'} = new Lire::DlfSchema( %attr );
     };
     error( $expat, $@ ) if $@;
+    return;
 }
 
 sub dlf_schema_end {
@@ -748,6 +991,7 @@ sub dlf_schema_end {
 	$expat->{'lire_curr_schema'}->check();
     };
     error( $expat, $@ ) if $@;
+    return;
 }
 
 sub derived_schema_start {
@@ -757,6 +1001,7 @@ sub derived_schema_start {
 	$expat->{'lire_curr_schema'} = new Lire::DerivedSchema( %attr );
     };
     error( $expat, $@ ) if $@;
+    return;
 }
 
 sub derived_schema_end {
@@ -765,6 +1010,7 @@ sub derived_schema_end {
 	$expat->{'lire_curr_schema'}->check();
     };
     error( $expat, $@ ) if $@;
+    return;
 }
 
 sub extended_schema_start {
@@ -774,6 +1020,7 @@ sub extended_schema_start {
 	$expat->{'lire_curr_schema'} = new Lire::ExtendedSchema( %attr );
     };
     error( $expat, $@ ) if $@;
+    return;
 }
 
 sub extended_schema_end {
@@ -782,14 +1029,16 @@ sub extended_schema_end {
 	$expat->{'lire_curr_schema'}->check();
     };
     error( $expat, $@ ) if $@;
+    return;
 }
 
 sub error {
     my ( $expat, $msg ) = @_;
 
-    my $line = $expat->current_line;
+    my $line = $expat->current_line();
 
     croak $msg, " at line ", $line, "\n";
+    return;
 }
 
 sub field_start {
@@ -800,31 +1049,30 @@ sub field_start {
     check_param( $attr{'type'}, 'type', \&check_type,
                  'invalid value for type attribute' );
 
-    my $pos = @{$expat->{'lire_curr_schema'}->{'fields_by_pos'}};
-    $expat->{'lire_curr_field'} = new Lire::Field( 'name'	    => $attr{'name'},
-                                                   'i18n_domain'    => 'lire-'.$expat->{'lire_curr_schema'}->superservice(),
-                                                   'type'	    => $attr{'type'},
-                                                   'pos'	    => $pos,
-                                                   'default'  => $attr{'default'},
-                                                   'label'    => $attr{'label'},
-                                               );
+    $expat->{'lire_curr_field'} =
+      new Lire::Field( 'name' => $attr{'name'},
+                       'i18n_domain' => 'lire-'. $expat->{'lire_curr_schema'}->superservice(),
+                       'type'	    => $attr{'type'},
+                       'label'    => $attr{'label'},
+                     );
+
+    return;
 }
 
 sub field_end {
     my ( $expat, $name ) = @_;
 
-    my $field  = $expat->{'lire_curr_field'};
-    my $schema = $expat->{'lire_curr_schema'};
-    $schema->{'fields_by_pos'}[$field->pos()]   = $field;
-    $schema->{'fields_by_name'}{$field->name()} = $field;
-
+    $expat->{'lire_curr_schema'}->add_field( $expat->{'lire_curr_field'} );
     delete $expat->{'lire_curr_field'};
+
+    return;
 }
 
 sub title_start {
     my ( $expat, $name ) = @_;
 
     $expat->{'lire_curr_title'} = "";
+    return;
 }
 
 sub in_schema_element {
@@ -853,12 +1101,14 @@ sub title_end {
     } else {
 	error( $expat, "encountered unexpected title" );
     }
+    return;
 }
 
 sub description_start {
     my ( $expat, $name ) = @_;
 
     $expat->{'lire_curr_desc'} = "";
+    return;
 }
 
 sub description_end {
@@ -873,6 +1123,7 @@ sub description_end {
     } else {
 	error( $expat, "encountered unexpected description" );
     }
+    return;
 }
 
 # keep perl happy
@@ -884,15 +1135,20 @@ __END__
 
 =head1 SEE ALSO
 
-Lire::Program(3pm), Lire::Field(3pm)
+Lire::Field(3pm), Lire::ExtendedSchema(3pm), Lire::DlfConverter(3pm),
+Lire::DerivedSchema(3pm)
+
+=head1 AUTHOR
+
+  Francis J. Lacoste <flacoste@logreport.org>
 
 =head1 VERSION
 
-$Id: DlfSchema.pm,v 1.44 2004/03/26 00:27:34 wsourdeau Exp $
+$Id: DlfSchema.pm,v 1.57 2004/08/23 21:18:03 flacoste Exp $
 
 =head1 COPYRIGHT
 
-Copyright (C) 2001, 2002 Stichting LogReport Foundation LogReport@LogReport.org
+Copyright (C) 2001, 2002, 2004 Stichting LogReport Foundation LogReport@LogReport.org
 
 This file is part of Lire.
 
@@ -911,9 +1167,5 @@ along with this program (see COPYING); if not, check with
 http://www.gnu.org/copyleft/gpl.html or write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 
-=head1 AUTHOR
-
-Francis J. Lacoste <flacoste@logreport.org>
-
 =cut
 
