@@ -3,14 +3,18 @@ package Lire::DlfStore;
 use strict;
 
 use Lire::DlfStream;
+use Lire::DlfAnalyserProcess;
 use Lire::DlfQuery;
 use Lire::SQLExt::Registry;
 use Lire::WeekCalculator;
+use Lire::Config::Index;
+use Lire::Config::ReportConfigIndex;
+use Lire::ReportConfig;
 
-use Lire::Utils qw/check_param check_object_param min max/;
+use Lire::Utils qw/check_param check_object_param min max unique/;
 
 use File::Path qw/mkpath/;
-use File::Basename qw/dirname/;
+use File::Basename qw/dirname basename/;
 use POSIX qw/strftime/;
 
 use Errno;
@@ -70,7 +74,7 @@ sub open {
     }
 
     $self->_load_config_file();
-    $self->{'_dbh'} = DBI->connect( "dbi:SQLite:dbname=" .
+    $self->{'_dbh'} = DBI->connect( "dbi:SQLite2:dbname=" .
                                     $self->{'_store_path'} . "/dlf.db", "", "",
                                     { 'RaiseError' => 1,
                                       'AutoCommit' => 0, } );
@@ -82,6 +86,7 @@ sub open {
     die "DlfStore '$store_path' is locked by process $locked_by\n"
       unless $locked_by == $$;
 
+    $self->_migrate_report_jobs();
     return $self;
 }
 
@@ -98,6 +103,44 @@ sub _load_config_file {
           new Lire::Config::ConfigFile( 'spec' => Lire::Config->config_spec(),
                                         'filename' => $config_file );
     }
+    Lire::Config::Index->set_index( 'store_report_configurations',
+                                    new Lire::Config::ReportConfigIndex( $self->{'_config'}->get( 'reports' ) ) );
+    return;
+}
+
+sub _migrate_report_jobs {
+    my $self = $_[0];
+
+    foreach my $job ( $self->{'_config'}->get( 'report_jobs' )->elements() ) {
+        $self->_migrate_report_job( $job )
+          if $job->is_set( 'superservice' );
+    }
+    return;
+}
+
+sub _migrate_report_job {
+    my ( $self, $job ) = @_;
+
+    my $super = $job->get( 'superservice' )->get();
+    foreach my $sched ( $job->get( 'schedules' )->elements() ) {
+        my $cfgref = $self->_find_config( $super,
+                                          $sched->get( 'report_cfg' )->get() );
+        $sched->get( 'report_config' )->set( $cfgref );
+    }
+    return;
+}
+
+sub _find_config {
+    my ( $self, $super, $file ) = @_;
+
+    my $id = basename( $file );
+    return $id if $self->has_report_config( $id );
+
+    my $cfg = new_from_file Lire::ReportConfig( $super, $file )->as_config_value( $id );
+    $cfg->{'spec'} = $self->{'_config'}->spec()->get( 'reports' )->get( 'report_cfg' );
+    $self->{'_config'}->get( 'reports' )->append( $cfg );
+
+    return $id;
 }
 
 =pod
@@ -123,6 +166,7 @@ sub close {
         delete $self->{'_dbh'};
         $self->{'_config'}->save()
           unless $in_destroy;
+        Lire::Config::Index->set_index( 'store_report_configurations', undef );
     }
 }
 
@@ -194,6 +238,63 @@ sub report_jobs {
     return $self->{'_config'}->get( 'report_jobs' )->as_value();
 }
 
+=pod
+
+=head2 has_report_config( $name )
+
+Returns true if there is a report configuration named $name in
+this DlfStore.
+
+=cut
+
+sub has_report_config {
+    my ( $self, $name ) = @_;
+
+    check_param( $name, 'name' );
+
+    foreach my $cfg ( $self->{'_config'}->get( 'reports' )->elements() ) {
+        return 1 if $cfg->get( 'id' )->get() eq $name;
+    }
+
+    return 0;
+}
+
+=pod
+
+=head2 report_configurations()
+
+Returns as an array ref the list of ReporConfig currently configured
+in the DlfStore
+
+=cut
+
+sub report_configurations {
+    my $self = $_[0];
+
+    return $self->{'_config'}->get( 'reports' )->as_value();
+}
+
+=pod
+
+=head2 get_report_config( $name )
+
+Returns the Lire::ReportConfig object named $name. Throws an exception
+if it doesn' exists.
+
+=cut
+
+sub get_report_config {
+    my ( $self, $name ) = @_;
+
+    check_param( $name, 'name' );
+    croak "there is no report configuration named '$name'"
+      unless $self->has_report_config( $name );
+
+    foreach my $cfg ( $self->{'_config'}->get( 'reports' )->elements() ) {
+        return $cfg->as_value() if $cfg->get( 'id' )->get() eq $name;
+    }
+}
+
 #------------------------------------------------------------------------
 # Method _create_store( )
 #
@@ -287,12 +388,13 @@ sub dlf_streams {
 
     my @streams = ();
     my $sth = $self->{'_dbh'}->table_info( "", "", "dlf_%", "TABLE" );
-    $sth->execute;
-    while ( my $table_info = $sth->fetchrow_hashref ) {
+    $sth->execute();
+    while ( my $table_info = $sth->fetchrow_hashref() ) {
         next unless $table_info->{'TABLE_NAME'} =~ /^dlf_(.*)/;
+        next if $table_info->{'TABLE_NAME'} =~ /_links$/;
         push @streams, $1;
     }
-    $sth->finish;
+    $sth->finish();
 
     return @streams;
 }
@@ -309,7 +411,89 @@ schema $name.
 sub has_dlf_stream {
     my ( $self, $name ) = @_;
 
-    return grep { $_ eq $name } $self->dlf_streams;
+    return grep { $_ eq $name } $self->dlf_streams();
+}
+
+=pod
+
+=head2 get_stream_config( $name )
+
+Returns the Lire::Config::Dictionary instance which contains the
+stream configuration for the $name DlfStream. This method will create
+an instance from the default if necessary. If $name isn't a valid
+schema name, this method will throw an error.
+
+=cut
+
+sub get_stream_config {
+    my ( $self, $name ) = @_;
+
+    check_param( $name, 'name' );
+    croak "schema '$name' doesn't exist"
+      unless Lire::DlfSchema->has_schema( $name );
+
+    my $streams_config = $self->{'_config'}->get( 'streams_config' );
+    foreach my $config ( $streams_config->elements() ) {
+        return $config if $config->name eq $name;
+    }
+
+    my $config = $streams_config->spec()->get( $name )->instance();
+    $streams_config->append( $config );
+
+    return $config;
+}
+
+=pod
+
+=head2 configured_dlf_streams()
+
+Returns the list of DlfStreams which are referenced by the store
+configuration. This is the result of dlf_streams() plus all schemas
+that exists and are used by one of the confiured ImportJob or
+DlfStreamSpec.
+
+=cut
+
+sub configured_dlf_streams {
+    my $self = $_[0];
+
+    my @streams = ( $self->dlf_streams(), @{ $self->_import_job_streams() } );
+
+    my %done = ();
+    while ( defined( my $s = shift @streams ) ) {
+        next unless Lire::DlfSchema->has_schema( $s );
+        next if exists $done{$s};
+        push @streams, @{ $self->_analyser_streams( $s ) };
+        $done{$s} = 1;
+    }
+    return sort keys %done;
+}
+
+sub _analyser_streams {
+    my ( $self, $name ) = @_;
+
+    my @streams = ();
+
+    my $cfg = $self->get_stream_config( $name );
+    foreach my $comp ( $cfg->spec()->components() ) {
+        next unless $comp->isa( 'Lire::Config::DlfAnalyserSpec' );
+        push @streams, $comp->name()
+          if $cfg->get( $comp->name() )->get_plugin() ne 'none';
+    }
+
+    return \@streams;
+}
+
+sub _import_job_streams {
+    my $self = $_[0];
+
+    my @streams = ();
+    foreach my $job ( @{ $self->import_jobs() } ) {
+        my $name = $job->converter();
+        push @streams, Lire::PluginManager->get_plugin( 'dlf_converter', $name )->schemas()
+          if Lire::PluginManager->has_plugin( 'dlf_converter', $name );
+    }
+    return \@streams;
 }
 
 =pod
@@ -334,6 +518,7 @@ of field names which should specify the sort order. Reverse sort order
 can be specified by prefixing the field's name by '-'.
 
 =cut
+
 sub open_dlf_stream {
     my ( $self, $name, $mode, $sort_spec ) = @_;
 
@@ -354,6 +539,66 @@ sub open_dlf_stream {
 
 }
 
+
+=pod
+
+=head2 run_analysers( $stream, [ $dlf_source ] )
+
+Runs all the configured analysers on the DLF stream $stream.
+$dlf_source limit the records which should be analysed.
+
+=cut
+
+sub run_analysers {
+    my ( $self, $stream, $dlf_source ) = @_;
+
+    check_param( $stream, 'stream' );
+
+    croak "no DLF stream '$stream' in this store"
+      unless $self->has_dlf_stream( $stream );
+
+    my $config = $self->get_stream_config( $stream )->as_value();
+    while ( my ( $stream, $analyser ) = each %$config ) {
+        next if $stream eq 'keep_days';
+        next if $analyser->{'plugin'} eq 'none';
+
+        my $process = new Lire::DlfAnalyserProcess( $self,
+                                                    $analyser->{'plugin'},
+                                                    $analyser->{'properties'},
+                                                    $dlf_source );
+        $process->run_analysis_job();
+        $self->run_analysers( $stream, $process->job_id() );
+    }
+
+    return;
+}
+
+=pod
+
+=head2 clean_streams()
+
+Remove records that are days older than what is configured in the
+'keep_days' parameter.
+
+=cut
+
+sub clean_streams {
+    my ($self, $time) = @_;
+
+    $time ||= time;
+
+    foreach my $name ( $self->dlf_streams() ) {
+        my $config = $self->get_stream_config( $name );
+        my $keep_days = $config->get( 'keep_days' )->as_value();
+        next unless $keep_days;
+        my $time = $time - 86400 * $keep_days;
+        my $stream = $self->open_dlf_stream( $name, 'w' );
+        $stream->clean( $time );
+        $stream->close();
+    }
+    return;
+}
+
 sub _dbh {
     return $_[0]{'_dbh'};
 }
@@ -474,23 +719,26 @@ sub find_report_source {
 sub _find_dlf_source {
     my ( $self, $job, $schedule, $time ) = @_;
 
-    my $none_source = { 'source' => 'none', 'coverage' => 0 };
-    return $none_source 
-      unless $self->has_dlf_stream( $job->superservice() );
-
+    my $avail_start = 0;
+    my $avail_end = 2**31;
     my $range = $schedule->period_range( $time );
-    my $stream = $self->open_dlf_stream( $job->superservice(), 'r' );
-    my $start = $stream->start_time();
-    my $end   = $stream->end_time();
-    $stream->close();
-    return $none_source
-      unless defined $start;
+    foreach my $schema ( @{ $schedule->report_config()->schemas() } ) {
+        next unless $self->has_dlf_stream( $schema );
 
-    my $avail_start = max( $range->[0],  $start );
-    my $avail_end   = min( $range->[1], $end );
-    return $none_source
-      if ( $avail_start > $end
-           || $avail_end < $start );
+        my $stream = $self->open_dlf_stream( $schema, 'r' );
+        my $start = $stream->start_time();
+        my $end   = $stream->end_time();
+        $stream->close();
+        next unless defined $start;
+
+        next if ( $start > $range->[1]
+                  || $end < $range->[0] );
+
+        $avail_start = max( $range->[0],  $start, $avail_start );
+        $avail_end   = min( $range->[1], $end, $avail_end );
+    }
+    return { 'source' => 'none', 'coverage' => 0 }
+      unless $avail_start;
 
     return { 'source' => 'dlf',
              'start' => $avail_start,
@@ -568,13 +816,13 @@ __END__
 
 Lire::DlfConverter(3pm)
 
-=head1 VERSION
-
-$Id: DlfStore.pm,v 1.28 2004/04/07 18:12:32 flacoste Exp $
-
 =head1 AUTHOR
 
-Francis J. Lacoste <flacoste@logreport.org>
+  Francis J. Lacoste <flacoste@logreport.org>
+
+=head1 VERSION
+
+$Id: DlfStore.pm,v 1.38 2004/10/09 18:18:59 flacoste Exp $
 
 =head1 COPYRIGHT
 
