@@ -5,7 +5,7 @@ use strict;
 use Carp;
 use POSIX qw/ ceil /;
 
-use Lire::DataTypes qw/ :special :xml /;
+use Lire::DataTypes qw/ check_xml_name /;
 use Lire::Report::ColumnInfo;
 use Lire::Utils qw/ check_param check_object_param /;
 
@@ -18,8 +18,8 @@ Lire::Report::GroupInfo - Object that groups columns created by the same aggrega
 =head1 SYNOPSIS
 
     my $info = $subreport->group_info( 0 );
-    print "Group's name: ", $info->name,   "\n";
-    print "Group's columns starts at: ", $info->index, "\n";
+    print "Group's name: ", $info->name(),   "\n";
+    print "Group's columns starts at: ", $info->index(), "\n";
 
 =head1 DESCRIPTION
 
@@ -38,22 +38,16 @@ another Lire::Report::GroupInfo object.
 =cut
 
 sub new {
-    my $proto = shift;
-    my $class = ref $proto || $proto;
-
-    my ( $parent, $name ) = @_;
+    my ( $class, $parent, $name ) = @_;
 
     check_param( $name, 'name', \&check_xml_name,
                  "name isn't a valid XML name" );
     check_object_param( $parent, 'parent', 'Lire::Report::GroupInfo' );
 
-    my $self = bless {
-                      'name'      => $name,
-                      'children'  => [],
-                      'parent'    => $parent,
-                     }, $class;
-
-    return $self;
+    return bless( { 'name'      => $name,
+                    'children'  => [],
+                    'parent'    => $parent },
+                  $class );
 }
 
 =pod
@@ -86,6 +80,7 @@ labels should be displayed in the table header.
 
 sub row_idx {
     $_[0]{'row_idx'} = $_[1] if @_ == 2;
+
     return $_[0]{'row_idx'};
 }
 
@@ -198,7 +193,7 @@ GroupInfo.
 =cut
 
 sub column_children {
-    return grep { $_->isa( 'Lire::Report::ColumnInfo' ) } $_[0]->children;
+    return grep { $_->isa( 'Lire::Report::ColumnInfo' ) } $_[0]->children();
 }
 
 =pod
@@ -215,13 +210,13 @@ sub categorical_names {
     my @names = ();
     foreach my $col ( $self->column_children() ) {
         push @names, $col->name()
-          if $col->class() eq 'categorical'
+          if $col->class() eq 'categorical';
     }
 
     return \@names;
 }
 
-=pod 
+=pod
 
 =head2 create_column_info( $name, $class, $type, [$label]])
 
@@ -283,23 +278,19 @@ sub create_group_info {
 # Returns the next column's index that should be used when a ColumnInfo or
 # GroupInfo object is added.
 sub next_column_index {
-    my ( $self ) = @_;
+    my $self = $_[0];
 
     croak ( "next_column_index: starting column index wasn't set" )
       unless defined $self->{'index'};
 
-    if ( @{$self->{'children'}} ) {
-        my $last = $self->{'children'}[$#{$self->{'children'}}];
-        if ( UNIVERSAL::isa( $last, "Lire::Report::GroupInfo" ) ) {
-            return $last->next_column_index();
-        } else {
-            # ColumnInfo
-            return $last->index() + 1;
-        }
-    } else {
-        # No columns yet
-        return $self->index();
-    }
+    return $self->index()
+      unless ( @{$self->{'children'}} );
+
+    my $last = $self->{'children'}[$#{$self->{'children'}}];
+
+    return ( UNIVERSAL::isa( $last, "Lire::Report::GroupInfo" )
+             ? $last->next_column_index()
+             : $last->index() + 1 );
 }
 
 =pod
@@ -469,7 +460,7 @@ sub assign_categorical_columns {
     my ( $self, $col_start, $cat_col_end  ) = @_;
 
     # The categorical columns in this group to process
-    my @cat_columns = grep { $_->class eq 'categorical' }
+    my @cat_columns = grep { $_->class() eq 'categorical' }
       $self->column_children();
 
     # The number of available categorical columns not assigned
@@ -481,7 +472,7 @@ sub assign_categorical_columns {
     my $col_no = $col_start;
     while ( my $col = shift @cat_columns ) {
         # + 1 since $col isn't in @cat_columns
-        my $span = ceil($cat_column_avail / (@cat_columns + 1));
+        my $span = ceil( $cat_column_avail / (@cat_columns + 1) );
         $col->col_start( $col_no );
         die "ASSERTION FAILED: span outside of the columns assigned to categorical data"
           if $col_no + $span -1 > $cat_col_end;
@@ -503,7 +494,7 @@ sub assign_categorical_columns {
 #
 # Returns the number of columns in this group and its subgroups
 sub count_columns {
-    my ( $self ) = @_;
+    my $self = $_[0];
 
     my $count = $self->column_children();
     foreach my $group ( $self->group_children() ) {
@@ -522,7 +513,7 @@ sub count_columns {
 sub count_categorical_columns {
     my ($self) = @_;
 
-    my $count = grep { $_->class eq 'categorical' } $self->column_children();
+    my $count = grep { $_->class() eq 'categorical' } $self->column_children();
     my @groups = $self->group_children();
 
     $count += $groups[0]->count_categorical_columns()
@@ -545,10 +536,10 @@ sub assign_numerical_columns {
 
     my $col_no = $col_start;
     my $group_processed = 0;
-    foreach my $child ( $self->children ) {
+    foreach my $child ( $self->children() ) {
         if ( $child->isa( 'Lire::Report::ColumnInfo' ) ) {
             # Already assigned
-            next if $child->class eq 'categorical';
+            next if $child->class() eq 'categorical';
 
             # Numerical column are always 1 in width
             $child->col_start( $col_no );
@@ -583,15 +574,12 @@ sub assign_numerical_columns {
 # as indentation for grouping purpose (consult the example in
 # compute_group_layout).
 sub assign_columns_width {
-    my ( $self ) = @_;
+    my $self = $_[0];
 
     foreach my $col ( $self->column_children() ) {
-        my $start = $col->col_start();
-        if ( $start == $col->col_end() ) {
-            $col->col_width( $col->max_chars )
-        } else {
-            $col->col_width( 2 )
-        }
+        $col->col_width( $col->col_start() == $col->col_end()
+                         ? $col->max_chars()
+                         : 2 );
     }
 
     foreach my $group ( $self->group_children() ) {
@@ -619,7 +607,7 @@ sub correct_spanning_column_width {
 
         # Check the width of the span
         my $width = 0;
-        foreach (my $i=$start; $i <= $end; $i++ ) {
+        foreach ( my $i = $start; $i <= $end; $i++ ) {
             $width += $table_info->column_info_by_col_start( $i )->col_width();
         }
 
@@ -632,9 +620,8 @@ sub correct_spanning_column_width {
         # and not a column index)
         my $extra = ceil( ($col->max_chars - $width) / ( $end - $start) );
 
-        foreach (my $i=$start+1; $i <= $end; $i++ ) {
+        foreach ( my $i = $start + 1; $i <= $end; $i++ ) {
             my $col = $table_info->column_info_by_col_start( $i );
-
             $col->col_width( $col->col_width + $extra );
         }
     }
@@ -655,7 +642,7 @@ sub write_report {
     my $pfx = ' ' x $indent;
 
     print $fh $pfx, qq{<lire:group-info name="$self->{'name'}" row-idx="$self->{'row_idx'}">\n};
-    foreach my $i ( $self->children ) {
+    foreach my $i ( $self->children() ) {
         $i->write_report( $fh, $indent + 1 );
     }
     print $fh $pfx, "</lire:group-info>\n";
@@ -666,10 +653,10 @@ sub write_report {
 #
 # Remove circular references
 sub delete {
-    my ( $self ) = @_;
+    my $self = $_[0];
 
-    foreach my $c ( $self->children ) {
-        $c->delete;
+    foreach my $c ( $self->children() ) {
+        $c->delete();
     }
 
     %$self = ();
@@ -690,7 +677,7 @@ Lire::Report::Subreport(3pm) Lire::Report::ColumnInfo(3pm)
 
 =head1 VERSION
 
-$Id: GroupInfo.pm,v 1.18 2004/03/26 00:27:33 wsourdeau Exp $
+$Id: GroupInfo.pm,v 1.21 2004/05/10 06:23:22 wsourdeau Exp $
 
 =head1 AUTHOR
 
