@@ -4,7 +4,7 @@ use strict;
 
 use Time::Local;
 
-use Lire::Logger;
+use Lire::Logger qw/ lr_debug lr_info lr_err /;
 use Lire::Time qw/ syslog2cal clf2cal date2cal getMonthName /;
 
 use vars qw/ $LTIME @syslog_flavours $debug /;
@@ -737,11 +737,11 @@ Lire::Email(3)
 
 =head1 AUTHORS
 
-Joost van Baal, Francis J. Lacoste.  Initial idea by Joost Kooij
+  Joost van Baal, Francis J. Lacoste.  Initial idea by Joost Kooij
 
 =head1 VERSION
 
-$Id: Syslog.pm,v 1.11 2004/03/26 00:27:34 wsourdeau Exp $
+$Id: Syslog.pm,v 1.13 2004/05/17 17:05:18 wsourdeau Exp $
 
 =head1 COPYRIGHT
 
