@@ -20,15 +20,21 @@ sub new {
     check_object_param( $userargs{'value'}, 'value',
                         'Lire::Config::Scalar' );
 
-    my %args = (
-                %userargs,
-                '-sbborder' => 1,
-                '-text' => $userargs{'value'}->get(),
-                '-onchange' => \&_on_change_cb,
-               );
-    my $self =  $class->Curses::UI::TextEntry::new( %args );
+    return
+      $class->Curses::UI::TextEntry::new( %userargs,
+                                          '-height' => 1,
+                                          '-sbborder' => 1,
+                                          '-text' => $userargs{'value'}->get(),
+                                          '-onchange' => \&_on_change_cb,
+                                        );
+}
 
-    return $self;
+sub layout {
+    my $self = $_[0];
+
+    $self->{'-height'} = 1;
+
+    return $self->SUPER::layout();
 }
 
 sub refresh_view {
@@ -43,6 +49,7 @@ sub _on_change_cb {
     my $self = $_[0];
 
     $self->{'value'}->set( $self->{'-text'} );
+    $self->run_event( 'onvaluechanged' );
 
     return;
 }
