@@ -9,17 +9,18 @@ use Fcntl;
 use File::Basename;
 use Carp;
 use Socket;  # for gethostbyaddr
+use Time::Local;
 
 use vars qw( @EXPORT_OK );
 
 BEGIN {
-    @EXPORT_OK	= qw/xml_encode diff_lists tilde_expand
-                     read_keyvalue_file write_keyvalue_file
-                     tempfile tempdir tmpdir min max ratio ratio100
-                     shell_quote file_content create_file
-                     sql_quote_name tree_apply item_index
-                     check_param check_object_param
-                     deep_copy host_by_addr /;
+    @EXPORT_OK	= qw/ xml_encode latex_encode diff_lists tilde_expand
+                      tempfile tempdir tmpdir min max ratio ratio100
+                      shell_quote indent file_content create_file
+                      sql_quote_name tree_apply item_index
+                      check_param check_object_param
+                      deep_copy host_by_addr is_url parse_url
+                      period_range unique text_for_width /;
 }
 
 =pod
@@ -30,7 +31,7 @@ Lire::Utils - Various general-purpose function.
 
 =head1 SYNOPSIS
 
-  use Lire:Utils qw/ xml_encode read_keyvalue_file write_keyvalue_file /;
+  use Lire:Utils qw/ xml_encode /;
 
 =head1 DESCRIPTION
 
@@ -59,9 +60,29 @@ sub xml_encode {
     return $value;
 }
 
+
 =pod
 
-=head2 tilde_expand($path)
+=head2 latex_encode( $str )
+
+Returns $str with all LaTeX special characters escaped.
+
+=cut
+
+sub latex_encode {
+    my $str = $_[0];
+
+    $str =~ s/\\/--LIRE--BACKSLASH--/g;
+    $str =~ s/([#\$&~_^%{}])/\\$1/g;
+    $str =~ s/(\[|\]|<|>)/\$$1\$/g;
+    $str =~ s/--LIRE--BACKSLASH--/\$\\backslash\$/g;
+
+    return $str;
+}
+
+=pod
+
+=head2 tilde_expand( $path )
 
 Does tilde-expansion on a path, if possible. This means that paths
 of the form ~/foo are transformed to something like /home/user/foo,
@@ -71,26 +92,27 @@ the form ~otheruser/foo are translated similary by a passwd lookup.
 =cut
 
 sub tilde_expand {
-	my $path = $_[0];
+    my $path = $_[0];
 
-	return $path if ord($path) != 126; # ascii code for ~
+    return $path if ord( $path ) != 126; # ascii code for ~
 
-	my ($tilde, $rest) = split('/', $path, 2);
+    my ( $tilde, $rest ) = split( '/', $path, 2 );
 
-	my $user = substr($tilde, 1); # skip the initial ~
+    my $user = substr( $tilde, 1 ); # skip the initial ~
 
-	if($user eq '') {
-		croak('$HOME not set')
-			unless exists $ENV{'HOME'};
-		$tilde = $ENV{'HOME'};
-	} else {
-		my ($name,$pass,$uid,$gid,$quota,$comment,$gecos,$dir) = getpwnam($user);
-		$tilde = $dir
-			if defined $dir;
-	}
-	$tilde .= "/$rest" if defined $rest;
+    if ( $user eq '' ) {
+        croak('$HOME not set')
+          unless exists $ENV{'HOME'};
+        $tilde = $ENV{'HOME'};
+    } else {
+        my ( $name, $pass, $uid, $gid, $quota, $comment, $gecos, $dir) =
+          getpwnam( $user );
+        $tilde = $dir
+          if defined $dir;
+    }
+    $tilde .= "/$rest" if defined $rest;
 
-	return $tilde;
+    return $tilde;
 }
 
 =pod
@@ -145,67 +167,6 @@ sub diff_lists {
 
 =pod
 
-=head2 read_keyvalue_file( $filename )
-
-Read file $filename and returns the its content as an hash reference.
-The file should contains lines in the form:
-
-  Key: value
-
-A key cannot appears more than once. A value cannot contains newline
-characters.
-
-=cut
-sub read_keyvalue_file {
-    my ( $filename ) = @_;
-
-    open my $fh, $filename
-      or croak "error opening file '$filename': $!";
-
-    my %content = ();
-    my $line;
-    while ( defined( $line = <$fh> ) ) {
-        chomp $line;
-        next if $line =~ m/^\s*$/;
-
-        my ($key, $value) = $line =~ m/([^:]+): (.*)/
-          or croak "can't parse line $. of '$filename'";
-
-        croak "key $key appears twice at line $. of '$filename'"
-          if exists $content{$key};
-        $content{$key} = $value;
-    }
-    close $fh;
-
-    \%content;
-}
-
-=pod
-
-=head2 write_keyvalue_file( $filename, $hash )
-
-Write the content of $hash into $filename in a form that can be read
-back by the read_keyvalue_file() function.
-
-=cut
-
-sub write_keyvalue_file {
-    my ( $filename, $hash ) = @_;
-
-
-    open my $fh, "> $filename"
-      or croak "cannot open file '$filename' for writing: $!";
-    while ( my ($key, $value) = each %$hash ) {
-        croak "values cannot span multiple lines: $value"
-          if defined $value && $value =~ /[\r\n]/;
-        print $fh $key, ": ", defined $value ? $value : "", "\n";
-    }
-    close $fh
-      or croak "error closing '$filename': $!";
-}
-
-=pod
-
 =head1 PORTABILITY FUNCTIONS
 
 For portability across Perl versions, this module defines some
@@ -221,11 +182,9 @@ temporary files should go.
 =cut
 
 sub tmpdir {
-    if ( File::Spec->can( "tmpdir" ) ) {
-	return File::Spec->tmpdir;
-    } else {
-	return _tmpdir();
-    }
+    return ( File::Spec->can( "tmpdir" )
+             ? return File::Spec->tmpdir
+             : _tmpdir() );
 }
 
 sub _tmpdir {
@@ -241,7 +200,7 @@ sub _tmpdir {
 
     my $fh = tempfile();
     my $fh = tempfile( $template, 'SUFFIX' => ".txt" )
-    my ($fh, $name ) = tempfile( $template, 'SUFFIX' => ".dlf" );
+    my ( $fh, $name ) = tempfile( $template, 'SUFFIX' => ".dlf" );
 
 This is a wrapper around the File::Temp::tempfile Perl function when
 available, and it offers a home grown version which should be safe
@@ -488,46 +447,126 @@ sub shell_quote {
 
 =pod
 
-=head2 file_content( $filename )
+=head2 indent( $string, [ $count ] )
 
-Returns the content of $filename. Dies if an error occurs.
+Return $string, indented by $count spaces. If $count is not specified, a
+default of 2 will be assumed.
 
 =cut
 
-sub file_content {
-    my $file = $_[0];
+sub indent {
+    my ( $text, $step ) = @_;
 
-    check_param( $file, 'filename' );
+    return ''
+      unless $text;
 
-    open my $fh, $file
-      or croak "failed to open '$file': $!";
-    local $/ = undef;
-    my $content = <$fh>;
-    close $fh;
+    $step = 2
+      unless defined $step;
 
-    return $content;
+    my @lines = split( /\n/, $text );
+    my $indented = join( "\n", map( { ' ' x $step . $_ } @lines ) );
+    $indented .= "\n"
+      if $text =~ m/\n$/;
+
+    return $indented;
 }
 
 =pod
 
-=head2 create_file( $filename, [$content] )
+=head2 check_param( $param, $name, [ $regex | $coderef, $msg ] )
 
-Creates file $filename with $content.
+Check that param "$name" is not undefined, and that it optionally match the
+given regexp. Validation can also be achieved through a code reference passed
+as the third parameter. The convention in this case is that the subroutine
+will return a boolean indicating whether $param is valid or not.
+
+Examples:
+
+    check_param( $req_param, 'req_param' );
+    check_param( $param_string, 'param_string', qr/^[a-z]+$/ );
+    check_param( $integer, 'integer', qr/^[0-9]+$/, "not a valid integer" );
+    check_param( $bool, 'bool', sub { return $_[0] }, "boolean was false" );
 
 =cut
 
-sub create_file {
-    my ( $filename, $content ) = @_;
+sub check_param {
+    my ( $param, $name, $regex, $msg ) = @_;
 
-    check_param( $filename, 'filename' );
+    my ( $package, $filename, $line ) = caller();
+    die "check_param needs at least 2 arguments: a parameter, the parameter\'s name at $filename:$line\n"
+      unless ( @_ >= 2 );
+    die "parameter 'name' is not a valid name: '$name' at $filename:$line\n"
+      unless ( $name =~ m/^[a-zA-Z0-9_]+$/ );
 
-    $content = ""
-      unless defined $content;
+    ( $package, $filename, $line ) = caller( 1 );
+    die "missing '$name' parameter at $filename:$line\n"
+      unless defined $param;
 
-    open my $fh, "> $filename"
-      or croak "error creating $filename: $!";
-    print $fh $content;
-    close $fh;
+    if ( defined $regex ) {
+        if ( ref $regex eq 'CODE' ) {
+            die ( defined $msg
+                  ? "$msg: '$param' at $filename:$line\n"
+                  : "'$name' parameter value ('$param') doesn't validate with subroutine at $filename:$line\n" )
+              unless ( $regex->( $param ) );
+        } else {
+            die ( defined $msg
+                  ? "$msg: '$param' at $filename:$line\n"
+                  : "'$name' parameter doesn't match '$regex': '$param' at $filename:$line\n" )
+              if ( $param !~ $regex );
+        }
+    }
+
+    return;
+}
+
+=pod
+
+=head2 check_param( $instance, $name, $class )
+
+Check that param "$instance" is a valid of one or more classes specified in
+the 'class' parameter. The latter being either a string or a reference to an
+array containing one or more such strings.
+
+Examples:
+
+    check_param( $object, 'object', 'Wawa::Class' );
+    check_param( $object, 'object', [ 'Wawa::Class', 'Other::Class' ] );
+
+=cut
+
+sub check_object_param {
+    my ( $instance, $name, $class ) = @_;
+
+    my ( $package, $filename, $line ) = caller();
+    die "check_object_param needs 3 arguments: an object, the object parameter's name, the object's class name at $filename:$line\n"
+      unless ( @_ == 3 );
+    die "parameter 'name' is not a valid name: '$name' at $filename:$line\n"
+      unless ( $name =~ m/^[a-zA-Z0-9_]+$/ );
+
+    $class = [ $class ]
+      unless ( ref $class eq 'ARRAY' );
+    die "parameter 'class' should contain at least one class name at $filename:$line\n"
+      unless ( @{$class} > 0 );
+
+    foreach my $cl ( @{$class} ) {
+        die "parameter 'class' contains an invalid class name: '$cl' at $filename:$line\n"
+          unless ( $cl =~ m/^[a-zA-Z0-9_]+(::[a-zA-Z0-9_]+)*$/ );
+    }
+
+    ( $package, $filename, $line ) = caller( 1 );
+    die "missing '$name' parameter at $filename:$line\n"
+      unless defined $instance;
+    foreach my $cl ( @{$class} ) {
+        return if UNIVERSAL::isa( $instance, $cl );
+    }
+
+    if ( @{$class} == 1 ) {
+        die "'$name' parameter should be a '$class->[0]' instance, not '$instance' at $filename:$line\n";
+    } else {
+        my $string = join "', '", @{$class}[0..@{$class}-2];
+        $string .= "' or '$class->[-1]" ;
+        die "'$name' parameter should be a '$string' instance, not '$instance' at $filename:$line\n";
+    }
 }
 
 =pod
@@ -629,6 +668,9 @@ sub _deep_copy {
         return _clone_array_ref( $object, $seen, $exclusions );
     } elsif ( ref $object eq 'HASH' ) {
         return _clone_hash_ref( $object, $seen, $exclusions );
+    } elsif ( ref $object eq 'Regexp' ) {
+        # This is a read-only object
+        return $object;
     } elsif ( UNIVERSAL::isa( $object, 'UNIVERSAL' ) ){ # blessed object
         return _clone_object( $object, $seen, $exclusions );
     } else {
@@ -693,109 +735,9 @@ sub _clone_object {
     }
 }
 
-=pod
-
-=head2 check_param( $param, $name, [ $regex | $coderef, $msg ] )
-
-Check that param "$name" is not undefined, and that it optionally match the
-given regexp. Validation can also be achieved through a code reference passed
-as the third parameter. The convention in this case is that the subroutine
-will return a boolean indicating whether $param is valid or not.
-
-Examples:
-
-    check_param( $req_param, 'req_param' );
-    check_param( $param_string, 'param_string', qr/^[a-z]+$/ );
-    check_param( $integer, 'integer', qr/^[0-9]+$/, "not a valid integer" );
-    check_param( $bool, 'bool', sub { return $_[0] }, "boolean was false" );
-
-=cut
-
-sub check_param {
-    my ( $param, $name, $regex, $msg ) = @_;
-
-    my ( $package, $filename, $line ) = caller();
-    die "check_param needs at least 2 arguments: a parameter, the parameter\'s name at $filename:$line\n"
-      unless ( @_ >= 2 );
-    die "parameter 'name' is not a valid name: '$name' at $filename:$line\n"
-      unless ( $name =~ m/^[a-zA-Z0-9_]+$/ );
-
-    ( $package, $filename, $line ) = caller( 1 );
-    die "missing '$name' parameter at $filename:$line\n"
-      unless defined $param;
-
-    if ( defined $regex ) {
-        if ( ref $regex eq 'CODE' ) {
-            die ( defined $msg
-                  ? "$msg: '$param' at $filename:$line\n"
-                  : "'$name' parameter value ('$param') doesn't validate with subroutine at $filename:$line\n" )
-              unless ( $regex->( $param ) );
-        } else {
-            die ( defined $msg
-                  ? "$msg: '$param' at $filename:$line\n"
-                  : "'$name' parameter doesn't match '$regex': '$param' at $filename:$line\n" )
-              if ( $param !~ $regex );
-        }
-    }
-
-    return;
-}
-
-=pod
-
-=head2 check_param( $instance, $name, $class )
-
-Check that param "$instance" is a valid of one or more classes specified in
-the 'class' parameter. The latter being either a string or a reference to an
-array containing one or more such strings.
-
-Examples:
-
-    check_param( $object, 'object', 'Wawa::Class' );
-    check_param( $object, 'object', [ 'Wawa::Class', 'Other::Class' ] );
-
-=cut
-
-sub check_object_param {
-    my ( $instance, $name, $class ) = @_;
-
-    my ( $package, $filename, $line ) = caller();
-    die "check_object_param needs 3 arguments: an object, the object parameter's name, the object's class name at $filename:$line\n"
-      unless ( @_ == 3 );
-    die "parameter 'name' is not a valid name: '$name' at $filename:$line\n"
-      unless ( $name =~ m/^[a-zA-Z0-9_]+$/ );
-
-    $class = [ $class ]
-      unless ( ref $class eq 'ARRAY' );
-    die "parameter 'class' should contain at least one class name at $filename:$line\n"
-      unless ( @{$class} > 0 );
-
-    foreach my $cl ( @{$class} ) {
-        die "parameter 'class' contains an invalid class name: '$cl' at $filename:$line\n"
-          unless ( $cl =~ m/^[a-zA-Z0-9_]+(::[a-zA-Z0-9_]+)*$/ );
-    }
-
-    ( $package, $filename, $line ) = caller( 1 );
-    die "missing '$name' parameter at $filename:$line\n"
-      unless defined $instance;
-    foreach my $cl ( @{$class} ) {
-        return if UNIVERSAL::isa( $instance, $cl );
-    }
-
-    if ( @{$class} == 1 ) {
-        die "'$name' parameter should be a '$class->[0]' instance, not '$instance' at $filename:$line\n";
-    } else {
-        my $string = join "', '", @{$class}[0..@{$class}-2];
-        $string .= "' or '$class->[-1]" ;
-        die "'$name' parameter should be a '$string' instance, not '$instance' at $filename:$line\n";
-    }
-}
-
-
 # could better use a Perl interface to getnameinfo(3)
 
 sub host_by_addr {
-
 ## perldoc -f gethostbyaddr
 ## # gethostbyaddr(3)
 ## # See also: logresolve, from e.g. the Debian apache-utils package
@@ -815,15 +757,246 @@ sub host_by_addr {
 ## #              A temporary error occurred on an authoritative name server.  Try
 ## #              again later.
 
-    my $ip =  $_[0] or die "usage: gethostbyaddr IPv4address\n";
+    my $ip = $_[0] or die "usage: gethostbyaddr IPv4address\n";
     my $iaddr = inet_aton($ip) or die "$ip isn't an IPv4 address\n";
     my $name;
 
-    unless($name  = gethostbyaddr($iaddr, AF_INET)){
+    unless ( $name = gethostbyaddr( $iaddr, AF_INET ) ) {
         warn "can't resolve $ip: $? ($!)\n";
         $name = undef;
     }
-    $name;
+
+    return $name;
+}
+
+=pod
+
+=head2 unique( $list )
+
+Returns an array reference with the duplicates elements of $list removed.
+
+=cut
+
+sub unique {
+    my $list = $_[0];
+    check_object_param( $list, 'list', 'ARRAY' );
+
+    my $unique = [];
+    my %cache = ();
+    foreach my $element ( @$list ) {
+        push @$unique, $element
+          unless exists $cache{$element};
+        $cache{$element} = 1;
+    }
+
+    return $unique;
+}
+
+=pod
+
+=head2 text_for_width( $text, $width )
+
+Returns a stripped-down representation of 'text', ensuring its length is
+shorter or equal to 'width'. If the original text already fits the given
+width, it is returned unchanged, otherwise, it is shortened and '...' is put
+in the middle to indicate the cut.
+
+=cut
+
+sub text_for_width {
+    my ( $text, $width ) = @_;
+
+    check_param( $text, 'text' );
+    check_param( $width, 'width',
+                 sub { return ( $_[0] =~ m/^[0-9]+$/ && $_[0] >= 5 ) },
+                 "'width' should be a positive, greater than or equal to 5, integer" );
+
+    my $length = length( $text );
+    return $text if $length <= $width;
+
+    my $segment = ( $width - 3 ) / 2;
+    my $start = substr( $text, 0, $segment );
+    $start =~ s/\s*$//g;
+    my $end = substr( $text, $length - $segment );
+    $end =~ s/^\s*//g;
+
+    return $start . '...' . $end;
+}
+
+=pod
+
+=head2 is_url( $string )
+
+Determines whether $string is a url or not, returning 'true' or 'false' as
+result code.
+
+=cut
+
+sub is_url {
+    my $string = $_[0];
+
+    check_param( $string, 'string' );
+
+    return $string =~ m@^[a-zA-Z0-9]+://@ || 0;
+}
+
+
+=pod
+
+=head2 parse_url( $string )
+
+Returns an hash reference containing keys for the following URL parts:
+'scheme', 'host', 'port', 'path', 'query', 'fragment'. The value will
+be empty if this wasn't present in the URL. This function is somewhat
+'http' bias and one should use the URI module for full blown URI
+parsing.
+
+The function dies if the URL cannot be parsed.
+
+=cut
+
+sub parse_url {
+    check_param( $_[0], 'url' );
+
+    # e.g.
+    # http://ds.internic.net/instructions/overview.html#WARNING
+
+    my ( $scheme, $authority, $path, $query, $fragment) = (
+      $_[0] =~ m/^
+        (?:
+          ([^:\/?\#]+):     # scheme
+        )?
+        (?:
+          \/\/([^\/?\#]*)   # authority
+        )?
+        ([^?\#]*)           # path
+        (?:
+          \?([^\#]*)        # query
+        )?
+        (?:
+          \#(.*)            # fragment
+        )?$/x
+    ) or die "invalid url: '$_[0]'";
+
+    # fullblown
+    #
+    #  authority     = server | reg_name
+    #  server        = [ [ userinfo "@" ] hostport ]
+    #  hostport      = host [ ":" port ]
+    #  host          = hostname | IPv4address
+    #
+    # is not yet supported
+    my ( $host, $port );
+    ( $host, $port ) = $authority =~ m/^([-\.a-zA-Z0-9]+)(?::(\d+))?$/
+        if defined $authority;
+
+    return {
+            'scheme' => $scheme,
+            'host' => $host,
+            'port' => $port,
+            'path' => $path,
+            'query' => $query,
+            'fragment' => $fragment
+            };
+}
+
+=pod
+
+=head2 file_content( $filename )
+
+Returns the content of $filename. Dies if an error occurs.
+
+=cut
+
+require Lire::Error;
+
+sub file_content {
+    my $file = $_[0];
+
+    check_param( $file, 'filename' );
+
+    open my $fh, $file
+      or croak( Lire::Error::file_not_readable( $file ) );
+    local $/ = undef;
+    my $content = <$fh>;
+    close $fh;
+
+    return $content;
+}
+
+=pod
+
+=head2 create_file( $filename, [$content], [$utf8_encoding] )
+
+Creates file $filename with $content. The $utf8_encoding flag specifies
+whether you want to keep strings in their UTF-8 encoding with versions of Perl
+that supports it (5.8.0 and above).
+
+=cut
+
+require Lire::I18N;
+
+sub create_file {
+    my ( $filename, $content, $utf8_encoding ) = @_;
+
+    check_param( $filename, 'filename' );
+
+    $content = ""
+      unless defined $content;
+
+    open( my $fh, '>', $filename )
+      or croak "error creating '$filename': $!";
+    Lire::I18N::set_fh_encoding( $fh, 'utf-8' )
+      if $utf8_encoding;
+    print $fh $content;
+    close $fh;
+
+    return;
+}
+
+=pod
+
+=head2 period_range( $period, $time )
+
+Returns an array reference containing the starting and ending
+boundaries for the $period that includes $time. $period should be
+one of 'hourly', 'daily', 'weekly', 'monthly' or 'yearly'. $time should
+be in seconds since epoch.
+
+=cut
+
+require Lire::WeekCalculator;
+
+sub period_range {
+    my ( $period, $time ) = @_;
+
+    check_param( $period, 'period', qr/^(hourly|daily|weekly|monthly|yearly)$/,
+                 "'period' parameter should be one of 'hourly', 'daily', 'weekly', 'monthly' or 'yearly'" );
+    check_param( $time, 'time', qr/^\d+$/, "'time' paremeter should be seconds since epoch" );
+
+    my ( $hour, $day, $month, $year ) = (localtime( $time || time() ))[2..5];
+    if ( $period eq 'hourly' ) {
+        my $start = timelocal( 0, 0, $hour, $day, $month, $year );
+        return [ $start, $start + 3600 ];
+    } elsif ( $period eq 'daily' ) {
+        my $start = timelocal( 0, 0, 0, $day, $month, $year );
+        return [ $start, $start + 3600*24 ];
+    } elsif ( $period eq 'weekly' ) {
+        my $calc = new Lire::WeekCalculator();
+        my $week_no = $calc->week_number( $time );
+        my $start = $calc->week_start( $year, $week_no );
+        return [ $start, $start + 86400*7 ];
+    } elsif ( $period eq 'monthly' ) {
+        my $start = timelocal( 0, 0, 0, 1, $month, $year );
+        if ( $month == 11 ) {
+            return [ $start, timelocal( 0, 0, 0, 1, 0, $year+1 ) ]
+        } else {
+            return [ $start, timelocal( 0, 0, 0, 1, $month + 1, $year ) ]
+        }
+    } elsif ( $period eq 'yearly' ) {
+        return [ timelocal( 0, 0, 0, 1, 0, $year ),
+                 timelocal( 0, 0, 0, 1, 0, $year+1 ) ]
+    }
 }
 
 # keep perl happy
@@ -833,16 +1006,16 @@ __END__
 
 =pod
 
-=head1 VERSION
-
-$Id: Utils.pm,v 1.42 2004/04/07 18:17:59 flacoste Exp $
-
 =head1 AUTHORS
 
-Francis J. Lacoste <flacoste@logreport.org>
-Joost van Baal <joostvb@logreport.org>
-Wessel Dankers <wsl@logreport.org>
-Wolfgang Sourdeau <wolfgang@logreport.org>
+  Francis J. Lacoste <flacoste@logreport.org>
+  Joost van Baal <joostvb@logreport.org>
+  Wessel Dankers <wsl@logreport.org>
+  Wolfgang Sourdeau <wolfgang@logreport.org>
+
+=head1 VERSION
+
+$Id: Utils.pm,v 1.63 2004/09/01 15:12:04 flacoste Exp $
 
 =head1 COPYRIGHT
 
@@ -867,5 +1040,3 @@ http://www.gnu.org/copyleft/gpl.html or write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 
 =cut
-
-
