@@ -4,23 +4,22 @@ use strict;
 
 use base qw/ Lire::Test::TestCase /;
 
-use File::Temp qw/ :mktemp /;
 use File::Spec;
-use Lire::Utils qw/xml_encode diff_lists tilde_expand
-                   read_keyvalue_file write_keyvalue_file
+use Lire::Utils qw/xml_encode latex_encode diff_lists tilde_expand
                    tmpdir tempfile tempdir min max ratio ratio100
                    shell_quote file_content create_file sql_quote_name
                    tree_apply item_index deep_copy
-                   check_param check_object_param
-                  /;
-use Carp;
+                   check_param check_object_param indent
+                   period_range text_for_width is_url parse_url
+                   unique /;
+use Time::Local;
+
+#our @TESTS = qw//;
 
 sub set_up {
     my $self = $_[0];
     $self->SUPER::set_up();
 
-    $self->{'file'} = mktemp( "keyvalueXXXXXX");
-
     return;
 }
 
@@ -28,7 +27,6 @@ sub tear_down {
     my $self = $_[0];
     $self->SUPER::tear_down();
 
-    unlink $self->{'file'};
     return;
 }
 
@@ -39,6 +37,12 @@ sub test_xml_encode {
     $self->assert_equals( "&lt;XML> &amp; &lt;/XML> Joe &quot;Such&quot; a Friend&apos;s birtday", $v );
 }
 
+sub test_latex_encode {
+    my $self = $_[0];
+
+    $self->assert_str_equals( '\\# \\$ \\& \\~ \\_ \\^ \\% \\{ \\} $\\backslash$ Other $[$ $]$ $<$ $>$',  latex_encode( '# $ & ~ _ ^ % { } \\ Other [ ] < >' ) );
+}
+
 sub test_diff_lists {
     my $self = $_[0];
 
@@ -62,38 +66,6 @@ sub test_diff_lists {
     $self->assert_deep_equals( [ "field5", "field6" ], $diff->{'new'} );
 }
 
-sub test_keyvalue_file {
-    my $self = $_[0];
-
-    my %dict = (
-                'Schema' => "www",
-                'Fields' => "field1 field2 field3 field4",
-               );
-
-    write_keyvalue_file( $self->{'file'}, \%dict );
-    $self->assert( -f $self->{'file'}, "File $self->{'file'} wasn't created" );
-    my $r = read_keyvalue_file( $self->{'file'} );
-    $self->assert_deep_equals( \%dict, $r );
-    unlink $self->{'file'};
-
-}
-
-sub test_keyvalue_file_with_nulls {
-    my $self = $_[0];
-
-    my %dict = (
-                'Records' => 0,
-                'Start-Time' => undef,
-                'End-Time' => undef,
-               );
-
-    write_keyvalue_file( $self->{'file'}, \%dict );
-    $self->assert( -f $self->{'file'}, "File $self->{'file'} wasn't created" );
-    my $r = read_keyvalue_file( $self->{'file'} );
-    $self->assert_deep_equals( \%dict, $r );
-    unlink $self->{'file'};
-}
-
 sub test_tilde_expansion {
     my $self = $_[0];
 
@@ -264,10 +236,10 @@ EOF
     print $fh $content;
     close $fh;
 
-    $self->assert_died( sub { file_content() },
-                        qr/missing 'filename' parameter/ );
-    $self->assert_died( sub { file_content( "/no/such/file" ) },
-                        qr/No such file/ );
+    $self->assert_dies( qr/missing 'filename' parameter/,
+                        sub { file_content() } );
+    $self->assert_dies( qr{could not open '/no/such/file' for reading},
+                        sub { file_content( "/no/such/file" ) } );
 
     $self->assert_equals( $content, file_content( $name ) );
     unlink $name;
@@ -276,6 +248,13 @@ EOF
 sub test_create_file {
     my $self = $_[0];
 
+    no warnings 'redefine';
+    my $encoding = undef;
+    my $set_fh_encoding = sub {
+        $encoding = 1;
+    };
+    local *Lire::I18N::set_fh_encoding = $set_fh_encoding;
+
     $self->assert_died( sub { create_file()}, 
                         qr/missing 'filename' parameter/ );
 
@@ -290,7 +269,9 @@ EOF
 
     my $tmpdir = File::Temp::tempdir( "Utils_XXXXXX", 'CLEANUP' => 1 );
     my $filename = "$tmpdir/test_file";
+
     create_file( $filename );
+
     $self->assert( -f $filename, "$filename wasn't created" );
     $self->assert( ! -s $filename, "$filename should be empty" );
 
@@ -298,12 +279,18 @@ EOF
 
     my $fh;
     open $fh, $filename
-      or croak "open failed: $!";
+      or $self->error( "open failed: $!" );
     local $/;
     my $new_content = <$fh>;
     close $fh;
 
     $self->assert_equals( $content, $new_content );
+
+    $self->assert_null( $encoding );
+    create_file( $filename, $content, 1 );
+    $self->assert_num_equals( 1, $encoding );
+
+    return;
 }
 
 sub test_sql_quote_name {
@@ -420,6 +407,9 @@ sub test_deep_copy {
     $self->assert_deep_equals( $array, deep_copy( $array ) );
     $self->assert_str_not_equals( $array, deep_copy( $array ) );
 
+    my $rx = qr/.*/;
+    $self->assert_str_equals( $rx, deep_copy( $rx ) );
+
     my $hash  = { 'key1' => $array,
                   'key2' => 1,
                   'key3' => $array, };
@@ -458,7 +448,7 @@ sub test_clone_scalar_ref {
         if ( ref $object eq 'REF' || ref $object eq 'SCALAR') {
             return Lire::Utils::_clone_scalar_ref( $object, $seen,$exclusions);
         } else {
-            croak "ref type unsupported by deep_copy(): $object";
+            $self->error( "ref type unsupported by deep_copy(): $object" );
         }
     };
 
@@ -492,7 +482,7 @@ sub test_clone_array_ref {
         if ( ref $object eq 'ARRAY' ) {
             return Lire::Utils::_clone_array_ref( $object, $seen, $exclusions);
         } else {
-            croak "ref type unsupported by deep_copy(): $object";
+            $self->error( "ref type unsupported by deep_copy(): $object" );
         }
     };
 
@@ -529,7 +519,7 @@ sub test_clone_hash_ref {
         if ( ref $object eq 'HASH' ) {
             return Lire::Utils::_clone_hash_ref( $object, $seen, $exclusions );
         } else {
-            croak "ref type unsupported by deep_copy(): $object";
+            $self->error( "ref type unsupported by deep_copy(): $object" );
         }
     };
 
@@ -683,6 +673,160 @@ sub test_check_object_param_caller {
     return;
 }
 
+
+sub test_indent {
+    my $self = $_[0];
+
+    $self->assert_str_equals( '', indent() );
+    $self->assert_str_equals( '', indent( '' ) );
+
+    my $start_text = 'simple line';
+    $self->assert_str_equals( '  simple line', indent( $start_text ) );
+
+    $start_text = <<_EOT;
+text for indentation
+  indented line
+end of indentation
+_EOT
+    my $e_text = <<_EOT;
+  text for indentation
+    indented line
+  end of indentation
+_EOT
+
+    $self->assert_str_equals( $e_text, indent( $start_text ) );
+
+    $e_text = <<_EOT;
+    text for indentation
+      indented line
+    end of indentation
+_EOT
+    $self->assert_str_equals( $e_text, indent( $start_text, 4 ) );
+
+    return;
+}
+
+sub test_period_range {
+    my $self = $_[0];
+
+    $self->{'cfg'}{'lr_week_numbering'} = 'U';
+    $self->set_up_tz( 'UTC' );
+
+    my $dec31_2004 = timelocal( 0, 5, 23, 31, 11, 2004 );
+    $self->assert_dies( qr/'period' parameter should be one of 'hourly', 'daily', 'weekly', 'monthly' or 'yearly'/,
+                        sub { period_range( 'unique', $dec31_2004 ) } );
+
+    $self->assert_deep_equals( [ timelocal( 0, 0, 23, 31, 11, 2004 ),
+                                 timelocal( 0, 0, 0, 1, 0, 2005 ) ],
+                               period_range( 'hourly', $dec31_2004 ) );
+
+    $self->assert_deep_equals( [ timelocal( 0, 0, 0, 31, 11, 2004 ),
+                                 timelocal( 0, 0, 0, 1, 0, 2005 ) ],
+                               period_range( 'daily', $dec31_2004 ) );
+
+    $self->assert_deep_equals( [ timelocal( 0, 0, 0, 1, 11, 2004 ),
+                                 timelocal( 0, 0, 0, 1, 0, 2005 ) ],
+                               period_range( 'monthly', $dec31_2004 ) );
+
+    my $jan1_2004 = timelocal( 0, 0, 0, 1, 0, 2004 );
+    $self->assert_deep_equals( [ timelocal( 0, 0, 0, 1, 0, 2004 ),
+                                 timelocal( 0, 0, 0, 1, 1, 2004 ) ],
+                               period_range( 'monthly', $jan1_2004 ) );
+
+    $self->assert_deep_equals( [ timelocal( 0, 0, 0, 1, 0, 2004 ),
+                                 timelocal( 0, 0, 0, 1, 0, 2005 ) ],
+                               period_range( 'yearly', $dec31_2004 ) );
+
+    $self->assert_deep_equals( [ timelocal( 0, 0, 0, 26, 11, 2004 ),
+                                 timelocal( 0, 0, 0, 2, 0, 2005 ) ],
+                               period_range( 'weekly', $dec31_2004 ) );
+}
+
+sub test_text_for_width {
+    my $self = $_[0];
+
+    $self->assert_dies( qr/missing \'text\' parameter/,
+                        sub { text_for_width() } );
+    $self->assert_dies( qr/missing \'width\' parameter/,
+                        sub { text_for_width( 'wawa' ) } );
+    $self->assert_dies( qr/\'width' should be a positive, greater than or equal to 5, integer: \'-3\'/,
+                        sub { text_for_width( 'wawa', -3 ) } );
+    $self->assert_dies( qr/\'width' should be a positive, greater than or equal to 5, integer: \'wawa\'/,
+                        sub { text_for_width( 'wawa', 'wawa' ) } );
+
+    $self->assert_str_equals( 'wawa',
+                              text_for_width( 'wawa', 10 ) );
+    $self->assert_str_equals( 'b...s',
+                              text_for_width( 'bigwawatestormorethan9chars', 5 ) );
+    $self->assert_str_equals( 'big...ars',
+                              text_for_width( 'big wawa test or more than 9 chars', 9 ) );
+    $self->assert_str_equals( 'big...hars',
+                              text_for_width( 'big wawa test or more than 10 chars', 10 ) );
+    $self->assert_str_equals( 'big...test',
+                              text_for_width( 'big           test', 10 ) );
+}
+
+sub test_is_url {
+    my $self = $_[0];
+
+    my $nourl_string1 = "/etc/lire";
+    my $nourl_string2 = "/etc/lire/file://tmp";
+    my $nourl_string3 = "file:/etc/lire/wawa";
+    my $nourl_string4 = "fi le://etc/lire/wawa";
+    my $url_string1 = "http://www.wawa.org";
+    my $url_string2 = "file:///tmp";
+    my $url_string3 = "file://c:/temp";
+
+    $self->assert_num_equals( 0, is_url( $nourl_string1 ) );
+    $self->assert_num_equals( 0, is_url( $nourl_string2 ) );
+    $self->assert_num_equals( 0, is_url( $nourl_string3 ) );
+    $self->assert_num_equals( 0, is_url( $nourl_string4 ) );
+    $self->assert_num_equals( 1, is_url( $url_string1 ) );
+    $self->assert_num_equals( 1, is_url( $url_string2 ) );
+    $self->assert_num_equals( 1, is_url( $url_string3 ) );
+
+    return;
+}
+
+sub test_parse_url {
+    my $self = $_[0];
+
+    $self->assert_deep_equals( { 'scheme' => 'http',
+                                 'host' => 'www.logreport.org',
+                                 'port' => 80,
+                                 'path' => '/index.html',
+                                 'query' => 'search=test',
+                                 'fragment' => 'anchor' },
+                               parse_url( 'http://www.logreport.org:80/index.html?search=test#anchor' ) );
+
+    $self->assert_deep_equals( { 'scheme' => 'http',
+                                 'host' => 'www.logreport.org',
+                                 'port' => undef,
+                                 'path' => '/index.html',
+                                 'query' => undef,
+                                 'fragment' => undef },
+                               parse_url( 'http://www.logreport.org/index.html' ) );
+
+
+    $self->assert_deep_equals( { 'scheme' => undef,
+                                 'host' => undef,
+                                 'port' => undef,
+                                 'path' => '/index.html',
+                                 'query' => undef,
+                                 'fragment' => 'anchor' },
+                               parse_url( '/index.html#anchor' ) );
+
+}
+
+sub test_unique {
+    my $self = $_[0];
+
+    $self->assert_deep_equals( [ 1, 2, 3 ],
+                               unique( [ 1, 2, 3, 1, 2, 3] ) );
+    $self->assert_deep_equals( [ 'aa', 'b', 'c' ],
+                               unique( [ 'aa', 'aa', 'aa', 'b', 'c' ] ) );
+}
+
 package tests::node;
 
 sub new {
