@@ -1,16 +1,13 @@
-# REFERENCE: firewall.cfg
+# REFERENCE: firewall_default.xml
 __( q{Messages Reports} );
-# REFERENCE: firewall.cfg
+# REFERENCE: firewall_default.xml
 __( q{Volume's Traffic Reports} );
-# REFERENCE: firewall.cfg
+# REFERENCE: firewall_default.xml
 __( q{Denied Packets Reports} );
 # REFERENCE: schema:firewall
 __( q{DLF Schema for Firewall service} );
 # REFERENCE: schema:firewall
-__( q{The <type>firewall</type> schema can be used for three types
-   of logs: packet filtering firewall, intrusion detection system
-   events and packet accounting devices.
-  } );
+__( q{The <type>firewall</type> schema can be used for three types of logs: packet filtering firewall, intrusion detection system events and packet accounting devices. } );
 # REFERENCE: schema:firewall
 __( q{Timestamp} );
 # REFERENCE: schema:firewall
@@ -18,18 +15,11 @@ __( q{The time of the event.} );
 # REFERENCE: schema:firewall
 __( q{Action} );
 # REFERENCE: schema:firewall
-__( q{What action was associated with that packet. Either
-    <constant>denied</constant> or
-    <constant>permitted</constant>. 
-   } );
+__( q{What action was associated with that packet. Either <constant>denied</constant> or <constant>permitted</constant>. } );
 # REFERENCE: schema:firewall
 __( q{Protocol} );
 # REFERENCE: schema:firewall
-__( q{The procotol of the packet. Common protocols are
-    <type>TCP</type>, <type>UDP</type> or <type>ICMP</type>. This
-    should be the <type>IP</type> protocol not higer-level application
-    protocol.
-   } );
+__( q{The procotol of the packet. Common protocols are <type>TCP</type>, <type>UDP</type> or <type>ICMP</type>. This should be the <type>IP</type> protocol not higer-level application protocol. } );
 # REFERENCE: schema:firewall
 __( q{Source IP} );
 # REFERENCE: schema:firewall
@@ -37,8 +27,7 @@ __( q{The source ip address on the packet.} );
 # REFERENCE: schema:firewall
 __( q{Src Port} );
 # REFERENCE: schema:firewall
-__( q{The source port (in the case of the TCP or UDP) protocol.
-    This should be the ICMP type when the protocol is ICMP.} );
+__( q{The source port (in the case of the TCP or UDP) protocol. This should be the ICMP type when the protocol is ICMP.} );
 # REFERENCE: schema:firewall
 __( q{Source Host} );
 # REFERENCE: schema:firewall
@@ -46,16 +35,11 @@ __( q{The hostname associated with the source IP.} );
 # REFERENCE: schema:firewall
 __( q{Recv Intf} );
 # REFERENCE: schema:firewall
-__( q{The receiving interface. That should be the network interface
-    on which the packet was received. That field should contains the
-    logical name or type of the interface.
-   } );
+__( q{The receiving interface. That should be the network interface on which the packet was received. That field should contains the logical name or type of the interface. } );
 # REFERENCE: schema:firewall
 __( q{Recv HW Address} );
 # REFERENCE: schema:firewall
-__( q{The hardware address of the receiving interface. That's the
-    MAC address in the case of an ethernet device.
-   } );
+__( q{The hardware address of the receiving interface. That's the MAC address in the case of an ethernet device. } );
 # REFERENCE: schema:firewall
 __( q{Destination IP} );
 # REFERENCE: schema:firewall
@@ -63,9 +47,7 @@ __( q{The destination ip address on the packet.} );
 # REFERENCE: schema:firewall
 __( q{Dst Port} );
 # REFERENCE: schema:firewall
-__( q{The destination port (in the case of the TCP or UDP) protocol.
-    This should be the ICMP code when the protocol is ICMP.
-   } );
+__( q{The destination port (in the case of the TCP or UDP) protocol. This should be the ICMP code when the protocol is ICMP. } );
 # REFERENCE: schema:firewall
 __( q{Destination host} );
 # REFERENCE: schema:firewall
@@ -73,46 +55,29 @@ __( q{The hostname associated with the destination IP.} );
 # REFERENCE: schema:firewall
 __( q{snt_intf} );
 # REFERENCE: schema:firewall
-__( q{The sending interface. That should be the network interface
-    on which the packet was sent (i.e. the outgoing interface).
-   } );
+__( q{The sending interface. That should be the network interface on which the packet was sent (i.e. the outgoing interface). } );
 # REFERENCE: schema:firewall
 __( q{Size} );
 # REFERENCE: schema:firewall
-__( q{The packet length (that is the header and payload length).
-    This should be the total length of the stream when the
-    event represent multiple packets, for example, in the case of
-    packet accounting done on streams.
-   } );
+__( q{The packet length (that is the header and payload length). This should be the total length of the stream when the event represent multiple packets, for example, in the case of packet accounting done on streams. } );
 # REFERENCE: schema:firewall
 __( q{Rule} );
 # REFERENCE: schema:firewall
-__( q{The rule that triggered that packet to be logged, denied,
-    permitted, etc.} );
+__( q{The rule that triggered that packet to be logged, denied, permitted, etc.} );
 # REFERENCE: schema:firewall
 __( q{Message} );
 # REFERENCE: schema:firewall
-__( q{A message associated with that packet. This could be an
-    attack signature detected by a Network Intrusion Detection System
-    or anything of similar nature.
-   } );
+__( q{A message associated with that packet. This could be an attack signature detected by a Network Intrusion Detection System or anything of similar nature. } );
 # REFERENCE: schema:firewall
 __( q{Count} );
 # REFERENCE: schema:firewall
-__( q{The number of packets described by this event. This will be 1
-    in the case of a single packet. It can be higher in the case where
-    multiple packets are compressed into one event. Remember that the
-    <type>length</type> values should reflect the length of all those packets.
-   } );
+__( q{The number of packets described by this event. This will be 1 in the case of a single packet. It can be higher in the case where multiple packets are compressed into one event. Remember that the <type>length</type> values should reflect the length of all those packets. } );
 # REFERENCE: report:firewall:bytes-by-period
 __( q{Bytes by Period Firewall Report} );
 # REFERENCE: report:firewall:bytes-by-period
-__( q{This report shows the number of bytes aggregated in
-    configurable time periods.} );
+__( q{This report shows the number of bytes aggregated in configurable time periods.} );
 # REFERENCE: report:firewall:bytes-by-period
-__( q{This parameter controls the time period over which the
-     bytes are aggregated.
-    } );
+__( q{This parameter controls the time period over which the bytes are aggregated. } );
 # REFERENCE: report:firewall:bytes-by-period
 __( q{Bytes by $period} );
 # REFERENCE: report:firewall:bytes-by-period
@@ -134,16 +99,9 @@ __( q{% Total} );
 # REFERENCE: report:firewall:bytes-by-timeslot
 __( q{Bytes by Timeslot Firewall Report} );
 # REFERENCE: report:firewall:bytes-by-timeslot
-__( q{This report shows the volume of traffic distributed by
-   timeslots (hours of the day, days of the week, etc.) that passed
-   (or were denied) by your firewall.
-  } );
+__( q{This report shows the volume of traffic distributed by timeslots (hours of the day, days of the week, etc.) that passed (or were denied) by your firewall. } );
 # REFERENCE: report:firewall:bytes-by-timeslot
-__( q{This parameter controls the length of the timeslot over
-     which the packets are aggregated. Use <userinput>1h</userinput>
-     for <quote>hours of the day</quote> or <userinput>1d</userinput>
-     for <quote>days of the week</quote>.
-    } );
+__( q{This parameter controls the length of the timeslot over which the packets are aggregated. Use <userinput>1h</userinput> for <quote>hours of the day</quote> or <userinput>1d</userinput> for <quote>days of the week</quote>. } );
 # REFERENCE: report:firewall:bytes-by-timeslot
 __( q{Volume of Traffic by $timeslot Timeslot} );
 # REFERENCE: report:firewall:bytes-by-timeslot
@@ -155,13 +113,9 @@ __( q{% Total} );
 # REFERENCE: report:firewall:bytesperfrom
 __( q{Top Bytes per From-IP Report} );
 # REFERENCE: report:firewall:bytesperfrom
-__( q{
-    This report lists the IP addresses sending the highest data volume.
-  } );
+__( q{ This report lists the IP addresses sending the highest data volume. } );
 # REFERENCE: report:firewall:bytesperfrom
-__( q{This parameter controls the number of sending IP adresses to
-     display in the report.
-    } );
+__( q{This parameter controls the number of sending IP adresses to display in the report. } );
 # REFERENCE: report:firewall:bytesperfrom
 __( q{Volume per sending IP, Top $ips_to_show} );
 # REFERENCE: report:firewall:bytesperfrom
@@ -171,23 +125,13 @@ __( q{% Total} );
 # REFERENCE: report:firewall:bytesperfromperport
 __( q{Top Bytes per From-IP per Port Report} );
 # REFERENCE: report:firewall:bytesperfromperport
-__( q{
-    This report lists the volume we were asked to receive per source IP per
-    source port.
-  } );
+__( q{ This report lists the volume we were asked to receive per source IP per source port. } );
 # REFERENCE: report:firewall:bytesperfromperport
-__( q{This parameter controls the number of source ports to display
-     in the report.
-    } );
+__( q{This parameter controls the number of source ports to display in the report. } );
 # REFERENCE: report:firewall:bytesperfromperport
-__( q{This parameter controls the number of sending IP adresses to
-     display in the report.
-    } );
+__( q{This parameter controls the number of sending IP adresses to display in the report. } );
 # REFERENCE: report:firewall:bytesperfromperport
-__( q{
-    Volume per source IP, per source port, Top $ips_to_show IPs, Top
-    $ports_to_show ports
-  } );
+__( q{ Volume per source IP, per source port, Top $ips_to_show IPs, Top $ports_to_show ports } );
 # REFERENCE: report:firewall:bytesperfromperport
 __( q{Volume} );
 # REFERENCE: report:firewall:bytesperfromperport
@@ -197,14 +141,9 @@ __( q{% Port} );
 # REFERENCE: report:firewall:bytesperto
 __( q{Top Bytes per To-ip Report} );
 # REFERENCE: report:firewall:bytesperto
-__( q{
-    This report lists the IP addresses for which we were asked to sent the
-    highest data volume to.
-  } );
+__( q{ This report lists the IP addresses for which we were asked to sent the highest data volume to. } );
 # REFERENCE: report:firewall:bytesperto
-__( q{This parameter controls the number of receiving IP adresses to
-     display in the report.
-    } );
+__( q{This parameter controls the number of receiving IP adresses to display in the report. } );
 # REFERENCE: report:firewall:bytesperto
 __( q{Volume per destination IP, Top $ips_to_show} );
 # REFERENCE: report:firewall:bytesperto
@@ -214,23 +153,13 @@ __( q{% Total} );
 # REFERENCE: report:firewall:bytespertoperport
 __( q{Top Bytes per destination IP per Port Report} );
 # REFERENCE: report:firewall:bytespertoperport
-__( q{
-    This report lists the volume were asked to receive per destination IP per
-    port.
-  } );
+__( q{ This report lists the volume were asked to receive per destination IP per port. } );
 # REFERENCE: report:firewall:bytespertoperport
-__( q{This parameter controls the number of ports to display
-     in the report.
-    } );
+__( q{This parameter controls the number of ports to display in the report. } );
 # REFERENCE: report:firewall:bytespertoperport
-__( q{This parameter controls the number of receiving IP adresses to
-     display in the report.
-    } );
+__( q{This parameter controls the number of receiving IP adresses to display in the report. } );
 # REFERENCE: report:firewall:bytespertoperport
-__( q{
-    Volume per destination IP, per port, Top $ips_to_show,
-    Top $ports_to_show ports
-  } );
+__( q{ Volume per destination IP, per port, Top $ips_to_show, Top $ports_to_show ports } );
 # REFERENCE: report:firewall:bytespertoperport
 __( q{Volume} );
 # REFERENCE: report:firewall:bytespertoperport
@@ -238,27 +167,15 @@ __( q{% Total} );
 # REFERENCE: report:firewall:bytespertoperport
 __( q{% Port} );
 # REFERENCE: report:firewall:deniedtcpperport
-__( q{
-  Top blocked tcp packets per source IP per destination port Report
- } );
+__( q{ Top blocked tcp packets per source IP per destination port Report } );
 # REFERENCE: report:firewall:deniedtcpperport
-__( q{
-    This report lists the destination ports for which we blocked the
-    highest tcp data volume, along with the sending ip adresses
-  } );
+__( q{ This report lists the destination ports for which we blocked the highest tcp data volume, along with the sending ip adresses } );
 # REFERENCE: report:firewall:deniedtcpperport
-__( q{This parameter controls the number of destination ports to display
-     in the report.
-    } );
+__( q{This parameter controls the number of destination ports to display in the report. } );
 # REFERENCE: report:firewall:deniedtcpperport
-__( q{This parameter controls the number of sending IP adresses to
-     display in the report.
-    } );
+__( q{This parameter controls the number of sending IP adresses to display in the report. } );
 # REFERENCE: report:firewall:deniedtcpperport
-__( q{
-   Volume per sending IP, per destination port, blocked TCP Packets,
-    Top $ips_to_show IPs, Top $ports_to_show ports
-  } );
+__( q{ Volume per sending IP, per destination port, blocked TCP Packets, Top $ips_to_show IPs, Top $ports_to_show ports } );
 # REFERENCE: report:firewall:deniedtcpperport
 __( q{Volume} );
 # REFERENCE: report:firewall:deniedtcpperport
@@ -268,13 +185,9 @@ __( q{% Port} );
 # REFERENCE: report:firewall:pkt-by-period
 __( q{Packets by Period Firewall Report} );
 # REFERENCE: report:firewall:pkt-by-period
-__( q{This report shows the number of packets logged by the firewall
-   aggregated in configurable time period.
-  } );
+__( q{This report shows the number of packets logged by the firewall aggregated in configurable time period. } );
 # REFERENCE: report:firewall:pkt-by-period
-__( q{This parameter controls the time period over which the
-     packets are aggregated.
-    } );
+__( q{This parameter controls the time period over which the packets are aggregated. } );
 # REFERENCE: report:firewall:pkt-by-period
 __( q{Packets by $period} );
 # REFERENCE: report:firewall:pkt-by-period
@@ -286,9 +199,7 @@ __( q{% Total} );
 # REFERENCE: report:firewall:pkt-by-rule
 __( q{Packets by Rule Firewall Report} );
 # REFERENCE: report:firewall:pkt-by-rule
-__( q{This report shows the number of packets logged by the firewall
-   for each rules.
-  } );
+__( q{This report shows the number of packets logged by the firewall for each rules. } );
 # REFERENCE: report:firewall:pkt-by-rule
 __( q{Packets by Rule} );
 # REFERENCE: report:firewall:pkt-by-rule
@@ -298,15 +209,9 @@ __( q{% Total} );
 # REFERENCE: report:firewall:pkt-by-timeslot
 __( q{Packets by Timeslot Firewall Report} );
 # REFERENCE: report:firewall:pkt-by-timeslot
-__( q{This report shows the number of packets distributed by
-   timeslots (hours of the day, days of the week, etc.).
-  } );
+__( q{This report shows the number of packets distributed by timeslots (hours of the day, days of the week, etc.). } );
 # REFERENCE: report:firewall:pkt-by-timeslot
-__( q{This parameter controls the length of the timeslot over
-     which the packets are aggregated. Use <userinput>1h</userinput>
-     for <quote>hours of the day</quote> or <userinput>1d</userinput>
-     for <quote>days of the week</quote>.
-    } );
+__( q{This parameter controls the length of the timeslot over which the packets are aggregated. Use <userinput>1h</userinput> for <quote>hours of the day</quote> or <userinput>1d</userinput> for <quote>days of the week</quote>. } );
 # REFERENCE: report:firewall:pkt-by-timeslot
 __( q{Packets by $timeslot Timeslot} );
 # REFERENCE: report:firewall:pkt-by-timeslot
@@ -318,18 +223,11 @@ __( q{% Total} );
 # REFERENCE: report:firewall:top-bytes-dst-by-src
 __( q{Top Volume to Destination by Source Firewall Report} );
 # REFERENCE: report:firewall:top-bytes-dst-by-src
-__( q{This report will show for a number of source IP addresses that
-   sent the most volume of traffic, the list of destination (destination IP and
-   destination port).
-  } );
+__( q{This report will show for a number of source IP addresses that sent the most volume of traffic, the list of destination (destination IP and destination port). } );
 # REFERENCE: report:firewall:top-bytes-dst-by-src
-__( q{This parameter controls the number of destination (IP
-     address and port) to display for each source IP.
-    } );
+__( q{This parameter controls the number of destination (IP address and port) to display for each source IP. } );
 # REFERENCE: report:firewall:top-bytes-dst-by-src
-__( q{This parameter controls the number of source IP adresses
-     to display in the report.
-    } );
+__( q{This parameter controls the number of source IP adresses to display in the report. } );
 # REFERENCE: report:firewall:top-bytes-dst-by-src
 __( q{Top Source IPs (in Volume of Traffic) by Destination, Top $src_to_show, Top $dst_to_show destinations} );
 # REFERENCE: report:firewall:top-bytes-dst-by-src
@@ -341,17 +239,11 @@ __( q{% IP} );
 # REFERENCE: report:firewall:top-bytes-src-by-dst
 __( q{Top Volume to Destination by Source Firewall Report} );
 # REFERENCE: report:firewall:top-bytes-src-by-dst
-__( q{This report will show for each destination (destination IP and
-   port) the list of source IPs that sent the most volume.
-  } );
+__( q{This report will show for each destination (destination IP and port) the list of source IPs that sent the most volume. } );
 # REFERENCE: report:firewall:top-bytes-src-by-dst
-__( q{This parameter controls the number of destination (IP
-     address and port) to display in the report.
-    } );
+__( q{This parameter controls the number of destination (IP address and port) to display in the report. } );
 # REFERENCE: report:firewall:top-bytes-src-by-dst
-__( q{This parameter controls the number of source IP adresses
-     that will be displayed for each destination.
-    } );
+__( q{This parameter controls the number of source IP adresses that will be displayed for each destination. } );
 # REFERENCE: report:firewall:top-bytes-src-by-dst
 __( q{Top Destinations (in Volume of Traffic) by Source IPs, Top $dst_to_show, Top $src_to_show source IPs} );
 # REFERENCE: report:firewall:top-bytes-src-by-dst
@@ -363,19 +255,13 @@ __( q{% Dest} );
 # REFERENCE: report:firewall:top-dst-by-msg
 __( q{Top Messages Firewall Report} );
 # REFERENCE: report:firewall:top-dst-by-msg
-__( q{This report shows the top destination IPs that are the target of
-   the messages (IDS alerts or others) generated by the firewall.
-  } );
+__( q{This report shows the top destination IPs that are the target of the messages (IDS alerts or others) generated by the firewall. } );
 # REFERENCE: report:firewall:top-dst-by-msg
-__( q{This parameter controls the number of messages to show in
-     the report.} );
+__( q{This parameter controls the number of messages to show in the report.} );
 # REFERENCE: report:firewall:top-dst-by-msg
-__( q{This parameter controls the number of destination IPS to list
-     with each message.
-    } );
+__( q{This parameter controls the number of destination IPS to list with each message. } );
 # REFERENCE: report:firewall:top-dst-by-msg
-__( q{Destination IPs by Message, Top $ips_to_show, Top
-  $msgs_to_show messages} );
+__( q{Destination IPs by Message, Top $ips_to_show, Top $msgs_to_show messages} );
 # REFERENCE: report:firewall:top-dst-by-msg
 __( q{Count} );
 # REFERENCE: report:firewall:top-dst-by-msg
@@ -385,12 +271,9 @@ __( q{% Message} );
 # REFERENCE: report:firewall:top-msg
 __( q{Top Messages Firewall Report} );
 # REFERENCE: report:firewall:top-msg
-__( q{This report shows the top messages (IDS alerts or others)
-  generated by the firewall.
-  } );
+__( q{This report shows the top messages (IDS alerts or others) generated by the firewall. } );
 # REFERENCE: report:firewall:top-msg
-__( q{This parameter controls the number of messages to show in
-     the report.} );
+__( q{This parameter controls the number of messages to show in the report.} );
 # REFERENCE: report:firewall:top-msg
 __( q{Top $msgs_to_show Messages} );
 # REFERENCE: report:firewall:top-msg
@@ -400,20 +283,13 @@ __( q{% Total} );
 # REFERENCE: report:firewall:top-pkt-by-dst-by-port
 __( q{Top Packets by Destination by Port Firewall Report} );
 # REFERENCE: report:firewall:top-pkt-by-dst-by-port
-__( q{This report will show for each destination IP the ports
-   that received the most packets.
-  } );
+__( q{This report will show for each destination IP the ports that received the most packets. } );
 # REFERENCE: report:firewall:top-pkt-by-dst-by-port
-__( q{This parameter controls the number of destination ports
-     that will be displayed for each destination.
-    } );
+__( q{This parameter controls the number of destination ports that will be displayed for each destination. } );
 # REFERENCE: report:firewall:top-pkt-by-dst-by-port
-__( q{This parameter controls the number of destination IPs
-     to display in the report.
-    } );
+__( q{This parameter controls the number of destination IPs to display in the report. } );
 # REFERENCE: report:firewall:top-pkt-by-dst-by-port
-__( q{Top Destinations by Port, Top $dst_to_show IPs, Top 
-   $ports_to_show destination ports} );
+__( q{Top Destinations by Port, Top $dst_to_show IPs, Top $ports_to_show destination ports} );
 # REFERENCE: report:firewall:top-pkt-by-dst-by-port
 __( q{Packets} );
 # REFERENCE: report:firewall:top-pkt-by-dst-by-port
@@ -423,14 +299,9 @@ __( q{% Dest} );
 # REFERENCE: report:firewall:top-pkt-by-dst
 __( q{Top Packets by Destination IP Report} );
 # REFERENCE: report:firewall:top-pkt-by-dst
-__( q{
-   This report lists the IP addresses that were listed as destination
-   in the most packets.
-  } );
+__( q{ This report lists the IP addresses that were listed as destination in the most packets. } );
 # REFERENCE: report:firewall:top-pkt-by-dst
-__( q{This parameter controls the number of destination IP adresses to
-     display in the report.
-    } );
+__( q{This parameter controls the number of destination IP adresses to display in the report. } );
 # REFERENCE: report:firewall:top-pkt-by-dst
 __( q{Packets by Destination IP, Top $ips_to_show} );
 # REFERENCE: report:firewall:top-pkt-by-dst
@@ -440,14 +311,9 @@ __( q{% Total} );
 # REFERENCE: report:firewall:top-pkt-by-src
 __( q{Top Packets by Source IP Report} );
 # REFERENCE: report:firewall:top-pkt-by-src
-__( q{
-   This report lists the IP addresses that were listed as source
-   in the most packets.
-  } );
+__( q{ This report lists the IP addresses that were listed as source in the most packets. } );
 # REFERENCE: report:firewall:top-pkt-by-src
-__( q{This parameter controls the number of source IP adresses to
-     display in the report.
-    } );
+__( q{This parameter controls the number of source IP adresses to display in the report. } );
 # REFERENCE: report:firewall:top-pkt-by-src
 __( q{Packets by Source IP, Top $ips_to_show} );
 # REFERENCE: report:firewall:top-pkt-by-src
@@ -457,18 +323,11 @@ __( q{% Total} );
 # REFERENCE: report:firewall:top-pkt-dst-by-src
 __( q{Top Packets Destination by Source Firewall Report} );
 # REFERENCE: report:firewall:top-pkt-dst-by-src
-__( q{This report will show for a number of source IP addresses that
-   sent the most packets, the list of destination (destination IP and
-   destination port).
-  } );
+__( q{This report will show for a number of source IP addresses that sent the most packets, the list of destination (destination IP and destination port). } );
 # REFERENCE: report:firewall:top-pkt-dst-by-src
-__( q{This parameter controls the number of destination (IP
-     address and port) to display for each source IP.
-    } );
+__( q{This parameter controls the number of destination (IP address and port) to display for each source IP. } );
 # REFERENCE: report:firewall:top-pkt-dst-by-src
-__( q{This parameter controls the number of source IP adresses
-     to display in the report.
-    } );
+__( q{This parameter controls the number of source IP adresses to display in the report. } );
 # REFERENCE: report:firewall:top-pkt-dst-by-src
 __( q{Top Source IPs by Destination, Top $src_to_show, Top $dst_to_show destinations} );
 # REFERENCE: report:firewall:top-pkt-dst-by-src
@@ -480,17 +339,11 @@ __( q{% IP} );
 # REFERENCE: report:firewall:top-pkt-src-by-dst
 __( q{Top Packets Source by Destination Firewall Report} );
 # REFERENCE: report:firewall:top-pkt-src-by-dst
-__( q{This report will show for each destination (destination IP and
-   port) the list of source IPs that sent the most packets.
-  } );
+__( q{This report will show for each destination (destination IP and port) the list of source IPs that sent the most packets. } );
 # REFERENCE: report:firewall:top-pkt-src-by-dst
-__( q{This parameter controls the number of destination (IP
-     address and port) to display in the report.
-    } );
+__( q{This parameter controls the number of destination (IP address and port) to display in the report. } );
 # REFERENCE: report:firewall:top-pkt-src-by-dst
-__( q{This parameter controls the number of source IP adresses
-     that will be displayed for each destination.
-    } );
+__( q{This parameter controls the number of source IP adresses that will be displayed for each destination. } );
 # REFERENCE: report:firewall:top-pkt-src-by-dst
 __( q{Top Destinations by Source IPs, Top $dst_to_show, Top $src_to_show source IPs} );
 # REFERENCE: report:firewall:top-pkt-src-by-dst
@@ -502,19 +355,13 @@ __( q{% Dest} );
 # REFERENCE: report:firewall:top-src-by-msg
 __( q{Top Messages Firewall Report} );
 # REFERENCE: report:firewall:top-src-by-msg
-__( q{This report shows the top source IPs that are at the origin of
-   the messages (IDS alerts or others) generated by the firewall.
-  } );
+__( q{This report shows the top source IPs that are at the origin of the messages (IDS alerts or others) generated by the firewall. } );
 # REFERENCE: report:firewall:top-src-by-msg
-__( q{This parameter controls the number of messages to show in
-     the report.} );
+__( q{This parameter controls the number of messages to show in the report.} );
 # REFERENCE: report:firewall:top-src-by-msg
-__( q{This parameter controls the number of source IPS to list
-     with each message.
-    } );
+__( q{This parameter controls the number of source IPS to list with each message. } );
 # REFERENCE: report:firewall:top-src-by-msg
-__( q{Source IPs by Message, Top $ips_to_show, Top
-  $msgs_to_show messages} );
+__( q{Source IPs by Message, Top $ips_to_show, Top $msgs_to_show messages} );
 # REFERENCE: report:firewall:top-src-by-msg
 __( q{Count} );
 # REFERENCE: report:firewall:top-src-by-msg
@@ -524,116 +371,48 @@ __( q{% Group} );
 # REFERENCE: filter:firewall:exclude-from-ip
 __( q{Exclude Source IP Filter} );
 # REFERENCE: filter:firewall:exclude-from-ip
-__( q{This filter specification can be used to select packets
-   sent from any host excluding the specified one.
-  } );
+__( q{This filter specification can be used to select packets sent from any host excluding the specified one. } );
 # REFERENCE: filter:firewall:exclude-from-ip
-__( q{This parameter contains the regular expression that will be
-     used to select the packets sent from any host, excluding the matching
-     one(s). Only
-     packets sent from a host not matching that regexp will be
-     included in the subreports. The match is done on the host's IP
-     address (not its hostname).
-    } );
+__( q{This parameter contains the regular expression that will be used to select the packets sent from any host, excluding the matching one(s). Only packets sent from a host not matching that regexp will be included in the subreports. The match is done on the host's IP address (not its hostname). } );
 # REFERENCE: filter:firewall:exclude-from-ip
-__( q{selected packets sent from IP addresses not matching
-   $ip-range ip} );
+__( q{selected packets sent from IP addresses not matching $ip-range ip} );
 # REFERENCE: filter:firewall:exclude-to-ip
 __( q{Exclude Destination IP Filter} );
 # REFERENCE: filter:firewall:exclude-to-ip
-__( q{This filter specification can be used to select packets
-   sent to any host excluding the specified one.
-  } );
+__( q{This filter specification can be used to select packets sent to any host excluding the specified one. } );
 # REFERENCE: filter:firewall:exclude-to-ip
-__( q{This parameter contains the regular expression that will be
-     used to select the packets sent to any host, excluding the matching
-     one(s). Only
-     packets sent to a host not matching that regexp will be
-     included in the subreports. The match is done on the host's IP
-     address (not its hostname).
-    } );
+__( q{This parameter contains the regular expression that will be used to select the packets sent to any host, excluding the matching one(s). Only packets sent to a host not matching that regexp will be included in the subreports. The match is done on the host's IP address (not its hostname). } );
 # REFERENCE: filter:firewall:exclude-to-ip
-__( q{selected packets sent to IP addresses not matching
-   $ip-range ip} );
+__( q{selected packets sent to IP addresses not matching $ip-range ip} );
 # REFERENCE: filter:firewall:select-action
 __( q{Select Action Filter} );
 # REFERENCE: filter:firewall:select-action
-__( q{This filter specification can be used to select only the
-   firewall events that were permitted or denied.
-  } );
+__( q{This filter specification can be used to select only the firewall events that were permitted or denied. } );
 # REFERENCE: filter:firewall:select-action
-__( q{This parameter contains the action that should selected:
-    <variablelist>
-      <varlistentry>
-       <term><constant>denied</constant></term>
-       <listitem>
-	<para>Select only denied events.</para>
-       </listitem>
-      </varlistentry>
-      <varlistentry>
-       <term><constant>permitted</constant></term>
-       <listitem>
-	<para>Select only permitted events.</para>
-       </listitem>
-      </varlistentry>
-      <varlistentry>
-      <term><constant>-</constant></term>
-       <listitem>
-	<para>This is also a possible action when we can't determine
-	from the log information if this event was
-	<constant>denied</constant> or <constant>permitted</constant>.
-       </para>
-       </listitem>
-      </varlistentry>
-     </variablelist>
-    } );
+__( q{This parameter contains the action that should selected: <variablelist> <varlistentry> <term><constant>denied</constant></term> <listitem> 	<para>Select only denied events.</para> </listitem> </varlistentry> <varlistentry> <term><constant>permitted</constant></term> <listitem> 	<para>Select only permitted events.</para> </listitem> </varlistentry> <varlistentry> <term><constant>-</constant></term> <listitem> 	<para>This is also a possible action when we can't determine 	from the log information if this event was 	<constant>denied</constant> or <constant>permitted</constant>. </para> </listitem> </varlistentry> </variablelist> } );
 # REFERENCE: filter:firewall:select-action
 __( q{$action_match events} );
 # REFERENCE: filter:firewall:select-from-ip
 __( q{Select Source IP Filter} );
 # REFERENCE: filter:firewall:select-from-ip
-__( q{This filter specification can be used to select the packets
-   coming from a particular host.
-  } );
+__( q{This filter specification can be used to select the packets coming from a particular host. } );
 # REFERENCE: filter:firewall:select-from-ip
-__( q{This parameter contains the regular expression that will be
-     used to select packets coming from particular hosts. Only
-     packets sent from a host matching that regexp will be
-     included in the subreports. The match is done on the client IP
-     address (not its hostname).
-    } );
+__( q{This parameter contains the regular expression that will be used to select packets coming from particular hosts. Only packets sent from a host matching that regexp will be included in the subreports. The match is done on the client IP address (not its hostname). } );
 # REFERENCE: filter:firewall:select-from-ip
-__( q{selected packets coming from IP addresses matching
-   $ip-range ip} );
+__( q{selected packets coming from IP addresses matching $ip-range ip} );
 # REFERENCE: filter:firewall:select-to-ip
 __( q{Select Destination IP Filter} );
 # REFERENCE: filter:firewall:select-to-ip
-__( q{This filter specification can be used to select packets
-   sent to a particular host.
-  } );
+__( q{This filter specification can be used to select packets sent to a particular host. } );
 # REFERENCE: filter:firewall:select-to-ip
-__( q{This parameter contains the regular expression that will be
-     used to select the packets sent to a particular host. Only
-     packets sent to a host matching that regexp will be
-     included in the subreports. The match is done on the host's IP
-     address (not its hostname).
-    } );
+__( q{This parameter contains the regular expression that will be used to select the packets sent to a particular host. Only packets sent to a host matching that regexp will be included in the subreports. The match is done on the host's IP address (not its hostname). } );
 # REFERENCE: filter:firewall:select-to-ip
-__( q{selected packets sent to IP addresses matching
-   $ip-range ip} );
+__( q{selected packets sent to IP addresses matching $ip-range ip} );
 # REFERENCE: filter:firewall:select-to-port
 __( q{Select Destination Port} );
 # REFERENCE: filter:firewall:select-to-port
-__( q{This filter specification can be used to select packets
-   sent to a particular port on the destination host.
-  } );
+__( q{This filter specification can be used to select packets sent to a particular port on the destination host. } );
 # REFERENCE: filter:firewall:select-to-port
-__( q{This parameter contains the regular expression that will be
-     used to select the packets sent to a particular port. Only
-     packets sent to a port matching that regexp will be
-     included in the subreports. The match is done on the ports symbolic
-     name, as found by Lire::Firewall's firewall_number2names routine.
-    } );
+__( q{This parameter contains the regular expression that will be used to select the packets sent to a particular port. Only packets sent to a port matching that regexp will be included in the subreports. The match is done on the ports symbolic name, as found by Lire::Firewall's firewall_number2names routine. } );
 # REFERENCE: filter:firewall:select-to-port
-__( q{selected packets sent to destination port matching
-   $port-range} );
+__( q{selected packets sent to destination port matching $port-range} );
